/*
 * This file is part of EasyRPG Player.
 *
 * EasyRPG Player is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EasyRPG Player is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EasyRPG Player. If not, see <http://www.gnu.org/licenses/>.
 */

#include "rtp_table.h"

namespace RTP {
	rtp_table_type RTP_TABLE_2003;
	rtp_table_type RTP_TABLE_2000;	
}

void RTP::Init() {
	static bool rtp_init = false;
	if (rtp_init) return;	
	rtp_init = true;
	
	RTP_TABLE_2003["backdrop"] = {
	 // Official English translation names
	 {"graveyard", "お墓"},
	 {"temple1", "お寺"},
	 {"dungeon1", "ダンジョン１"},
	 {"dungeon2", "ダンジョン２"},
	 {"dungeon3", "ダンジョン３"},
	 {"dungeon4", "ダンジョン４"},
	 {"dungeon5", "ダンジョン５"},
	 {"dungeon6", "ダンジョン６"},
	 {"universe", "宇宙"},
	 {"mountain road", "山道"},
	 {"rocky road", "岩場"},
	 {"ruins1", "廃墟"},
	 {"old town", "旧市街"},
	 {"forest1", "森１"},
	 {"forest2", "森２"},
	 {"bridge", "橋"},
	 {"swamp", "毒沼"},
	 {"mansion", "洋館"},
	 {"sea", "海"},
	 {"castle", "玉座"},
	 {"space", "異空間"},
	 {"beach", "砂浜"},
	 {"desert", "砂漠"},
	 {"temple2", "神殿"},
	 {"sky", "空"},
	 {"ship", "船上"},
	 {"grassland", "草原"},
	 {"wasteland", "荒地"},
	 {"town", "街中"},
	 {"road", "路上"},
	 {"ruins2", "遺跡"},
	 {"bathhouse", "銭湯"},
	 {"arena", "闘技場"},
	 {"snow field", "雪原"},

	 // RPG Advocate English translation names
	 {"shrine", "お寺"},
	 {"space", "宇宙"},
	 {"mountain", "山道"},
	 {"rockbed", "岩場"},
	 {"wasteland", "廃墟"},
	 {"ghost-town", "旧市街"},
	 {"building", "洋館"},
	 {"ocean", "海"},
	 {"strange", "異空間"},
	 {"ruins1", "神殿"},
	 {"shipdeck", "船上"},
	 {"plains", "草原"},
	 {"barren", "荒地"},
	 {"bath", "銭湯"},
	 {"snowfield", "雪原"},

	 // Unknown English translation names used by Spanish games
	 {"grave", "お墓"},
	 {"temple", "お寺"},
	 {"donjohn1", "ダンジョン１"},
	 {"donjohnq", "ダンジョン２"},
	 {"donjohnr", "ダンジョン３"},
	 {"donjohns", "ダンジョン４"},
	 {"donjohnt", "ダンジョン５"},
	 {"donjohnu", "ダンジョン６"},
	 {"mountainpath", "山道"},
	 {"rocks", "岩場"},
	 {"oldurban", "旧市街"},
	 {"forestp", "森１"},
	 {"forestq", "森２"},
	 {"poisonswamp", "毒沼"},
	 {"westernstylebuilding", "洋館"},
	 {"ballseat", "玉座"},
	 {"strangespacial", "異空間"},
	 {"sandybeach", "砂浜"},
	 {"sanctuary", "神殿"},
	 {"empty", "空"},
	 {"onboat", "船上"},
	 {"grassyplain", "草原"},
	 {"roughforging", "荒地"},
	 {"city", "街中"},
	 {"ruins", "遺跡,"},
	 {"competitionplace", "闘技場"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"cave", "ダンジョン１"},
	 {"lavacave", "ダンジョン２"},
	 {"icecave", "ダンジョン３"},
	 {"stalagmites", "ダンジョン４"},
	 {"labyrinth", "ダンジョン５"},
	 {"traininghall", "ダンジョン６"},
	 {"ruins", "廃墟"},
	 {"city", "旧市街"},
	 {"insidecastle", "洋館"},
	 {"spacelight", "異空間"},
	 {"clouds", "空"},
	 {"grass", "草原"},
	 {"cityhouse", "街中"},
	 {"insidepyramid", "遺跡"},
	 {"snow", "雪原"},

	 // 2000 RTP names not overwritten by Vlad Kovnerov's installation
	 {"cave1", "ダンジョン１"},
	 {"lavacave2", "ダンジョン２"},
	 {"icecave3", "ダンジョン３"},
	 {"cave4", "ダンジョン４"},
	 {"brickcave5", "ダンジョン５"},
	 {"galaxy", "宇宙"},
	 {"canyon", "山道"},
	 {"snowcanyon", "岩場"},
	 {"wasteruins", "廃墟"},
	 {"lightspeed", "異空間"},
	 {"seabeach", "砂浜"},
	 {"greece", "神殿"},

	 // Korean RTP
	 {"던젼１", "ダンジョン１"},
	 {"던젼２", "ダンジョン２"},
	 {"던젼３", "ダンジョン３"},
	 {"던젼４", "ダンジョン４"},
	 {"던젼５", "ダンジョン５"},
	 {"던젼６", "ダンジョン６"},
	 {"바닥", "お墓"},
	 {"우주", "宇宙"},
	 {"절", "お寺"},
	 {"산길", "山道"},
	 {"바위", "岩場"},
	 {"폐허", "廃墟"},
	 {"구시가지", "旧市街"},
	 {"숲１", "森１"},
	 {"숲２", "森２"},
	 {"다리", "橋"},
	 {"독연못", "毒沼"},
	 {"양관(서양식집)", "洋館"},
	 {"바다", "海"},
	 {"옥좌", "玉座"},
	 {"이공간", "異空間"},
	 {"사구", "砂浜"},
	 {"사막", "砂漠"},
	 {"신전", "神殿"},
	 {"하늘", "空"},
	 {"선상", "船上"},
	 {"초원", "草原"},
	 {"황야", "荒地"},
	 {"길가운데", "街中"},
	 {"도로 위", "路上"},
	 {"유적", "遺跡"},
	 {"공중 목욕탕", "銭湯"},
	 {"투기장", "闘技場"},
	 {"설원", "雪原"}
	};

	RTP_TABLE_2003["battle"] = {
	 // Official English translation names
	 {"2003 other1", "2003その他1"},
	 {"2003 other2", "2003その他2"},
	 {"2003 barrier", "2003バリア"},
	 {"2003 breath", "2003ブレス"},
	 {"2003 light pillar", "2003光柱"},
	 {"2003 cold", "2003冷気"},
	 {"2003 sword", "2003剣"},
	 {"2003 absorb", "2003吸収"},
	 {"2003 recovery", "2003回復"},
	 {"2003 earth", "2003大地"},
	 {"2003 bow", "2003弓"},
	 {"2003 blow", "2003打撃"},
	 {"2003 axe", "2003斧"},
	 {"2003 dark", "2003暗黒"},
	 {"2003 spear", "2003槍"},
	 {"2003 water", "2003水"},
	 {"2003 cure", "2003治療"},
	 {"2003 fire", "2003炎"},
	 {"2003 explosion", "2003爆発"},
	 {"2003 claw", "2003爪"},
	 {"2003 holy", "2003神聖"},
	 {"2003 revive", "2003蘇生"},
	 {"2003 thunder", "2003雷"},
	 {"2003 whip", "2003鞭"},
	 {"2003 wind", "2003風"},
	 {"2003 Paralysis", "2003麻痺"},
	 {"other", "その他"},
	 {"barrier", "バリア"},
	 {"breath", "ブレス"},
	 {"buff", "上昇"},
	 {"debuff", "下降"},
	 {"ice", "冷気"},
	 {"sword1", "剣1"},
	 {"sword2", "剣2"},
	 {"bite", "吸収"},
	 {"recovery", "回復"},
	 {"earth", "大地"},
	 {"blow", "打撃"},
	 {"axe", "斧"},
	 {"dark", "暗黒"},
	 {"spear", "槍"},
	 {"water", "水"},
	 {"treatment", "治療"},
	 {"fire1", "炎1"},
	 {"fire2", "炎2"},
	 {"explosion", "爆発"},
	 {"claw", "爪"},
	 {"arrow", "矢"},
	 {"holy", "神聖"},
	 {"ressurection", "蘇生"},
	 {"thunder", "雷"},
	 {"whip", "鞭"},
	 {"wind", "風"},
	 {"paralysis", "麻痺"},

	 // RPG Advocate English translation names
	 {"misc1", "2003その他1"},
	 {"misc2", "2003その他2"},
	 {"barrier1", "2003バリア"},
	 {"breath1", "2003ブレス"},
	 {"lightray", "2003光柱"},
	 {"ice1", "2003冷気"},
	 {"sword1", "2003剣"},
	 {"absorb1", "2003吸収"},
	 {"healing1", "2003回復"},
	 {"earth1", "2003大地"},
	 {"bow1", "2003弓"},
	 {"strike", "2003打撃"},
	 {"axe1", "2003斧"},
	 {"dark1", "2003暗黒"},
	 {"spear1", "2003槍"},
	 {"water1", "2003水"},
	 {"cure1", "2003治療"},
	 {"fire1", "2003炎"},
	 {"explode1", "2003爆発"},
	 {"claw1", "2003爪"},
	 {"holy1", "2003神聖"},
	 {"revive1", "2003蘇生"},
	 {"bolt1", "2003雷"},
	 {"whip1", "2003鞭"},
	 {"wind1", "2003風"},
	 {"paralyze1", "2003麻痺"},
	 {"misc3", "その他"},
	 {"barrier2", "バリア"},
	 {"breath2", "ブレス"},
	 {"increase", "上昇"},
	 {"decrease", "下降"},
	 {"ice2", "冷気"},
	 {"sword2", "剣1"},
	 {"sword3", "剣2"},
	 {"absorb2", "吸収"},
	 {"healing2", "回復"},
	 {"earth2", "大地"},
	 {"attack", "打撃"},
	 {"axe2", "斧"},
	 {"dark2", "暗黒"},
	 {"spear2", "槍"},
	 {"water2", "水"},
	 {"cure2", "治療"},
	 {"fire2", "炎1"},
	 {"fire3", "炎2"},
	 {"explode2", "爆発"},
	 {"claw2", "爪"},
	 {"bow2", "矢"},
	 {"holy2", "神聖"},
	 {"revive2", "蘇生"},
	 {"bolt2", "雷"},
	 {"whip2", "鞭"},
	 {"wind2", "風"},
	 {"paralyze2", "麻痺"},

	 // Unknown English translation names used by Spanish games
	 {"2003addition1", "2003その他1"},
	 {"2003addition2", "2003その他2"},
	 {"2003barrier", "2003バリア"},
	 {"2003breath", "2003ブレス"},
	 {"2003luminouspillar", "2003光柱"},
	 {"2003coldair", "2003冷気"},
	 {"2003sword", "2003剣"},
	 {"2003absorption", "2003吸収"},
	 {"2003recovery", "2003回復"},
	 {"2003ground", "2003大地"},
	 {"2003bow", "2003弓"},
	 {"2003shock", "2003打撃"},
	 {"2003ax", "2003斧"},
	 {"2003dark", "2003暗黒"},
	 {"2003spear", "2003槍"},
	 {"2003water", "2003水"},
	 {"2003remedy", "2003治療"},
	 {"2003flame", "2003炎"},
	 {"2003explosive", "2003爆発"},
	 {"2003nail", "2003爪"},
	 {"2003holy", "2003神聖"},
	 {"2003revival", "2003蘇生"},
	 {"2003thunder", "2003雷"},
	 {"2003rod", "2003鞭"},
	 {"2003wind", "2003風"},
	 {"2003paralysis", "2003麻痺"},
	 {"addition", "その他"},
	 {"rise", "上昇"},
	 {"drop", "下降"},
	 {"coldair", "冷気"},
	 {"absorption", "吸収"},
	 {"ground", "大地"},
	 {"shock", "打撃"},
	 {"ax", "斧"},
	 {"remedy", "治療"},
	 {"flame1", "炎1"},
	 {"flame2", "炎2"},
	 {"explosive", "爆発"},
	 {"nail", "爪"},
	 {"bow", "矢"},
	 {"revivial", "蘇生"},
	 {"rod", "鞭"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"2003-other1", "2003その他1"},
	 {"2003-other2", "2003その他2"},
	 {"2003-barrier", "2003バリア"},
	 {"2003-poison", "2003ブレス"},
	 {"2003-lines", "2003光柱"},
	 {"2003-cold", "2003冷気"},
	 {"2003-sword", "2003剣"},
	 {"2003-absorption", "2003吸収"},
	 {"2003-sun", "2003回復"},
	 {"2003-earth", "2003大地"},
	 {"2003-arrow", "2003弓"},
	 {"2003-hit", "2003打撃"},
	 {"2003-axe", "2003斧"},
	 {"2003-dark", "2003暗黒"},
	 {"2003-spear", "2003槍"},
	 {"2003-water", "2003水"},
	 {"2003-sphere", "2003治療"},
	 {"2003-fire", "2003炎"},
	 {"2003-explosion", "2003爆発"},
	 {"2003-claws", "2003爪"},
	 {"2003-holy", "2003神聖"},
	 {"2003-angel", "2003蘇生"},
	 {"2003-zip", "2003雷"},
	 {"2003-whip", "2003鞭"},
	 {"2003-wind", "2003風"},
	 {"2003-paralysis", "2003麻痺"},

	 // 2000 RTP names not overwritten by Vlad Kovnerov's installation
	 {"etc", "その他"},
	 {"poison", "ブレス"},
	 {"up", "上昇"},
	 {"down", "下降"},
	 {"cold", "冷気"},
	 {"sun", "回復"},
	 {"hit", "打撃"},
	 {"sphere", "治療"},
	 {"fang", "爪"},
	 {"ray", "蘇生"},
	 {"zip", "雷"},

	 // Korean RTP
	 {"검1", "剣1"},
	 {"화염1", "炎1"},
	 {"2003기타1", "2003その他1"},
	 {"2003기타2", "2003その他2"},
	 {"2003베리어", "2003バリア"},
	 {"2003브레스", "2003ブレス"},
	 {"2003주위의 빛", "2003光柱"},
	 {"2003냉기", "2003冷気"},
	 {"2003검", "2003剣"},
	 {"2003흡수", "2003吸収"},
	 {"2003회복", "2003回復"},
	 {"2003대지", "2003大地"},
	 {"2003화살", "2003弓"},
	 {"2003타격", "2003打撃"},
	 {"2003도끼", "2003斧"},
	 {"2003암흑", "2003暗黒"},
	 {"2003창", "2003槍"},
	 {"2003물", "2003水"},
	 {"2003치료", "2003治療"},
	 {"2003화염", "2003炎"},
	 {"2003폭발", "2003爆発"},
	 {"2003손톱", "2003爪"},
	 {"2003신성", "2003神聖"},
	 {"2003소생", "2003蘇生"},
	 {"2003전격", "2003雷"},
	 {"2003채찍", "2003鞭"},
	 {"2003바람", "2003風"},
	 {"2003마비", "2003麻痺"},
	 {"검2", "剣2"},
	 {"화염2", "炎2"},
	 {"브레스", "ブレス"},
	 {"베리어", "バリア"},
	 {"상승", "上昇"},
	 {"하강", "下降"},
	 {"기타", "その他"},
	 {"냉기", "冷気"},
	 {"흡수", "吸収"},
	 {"회복", "回復"},
	 {"대지", "大地"},
	 {"타격", "打撃"},
	 {"도끼", "斧"},
	 {"암흑", "暗黒"},
	 {"창", "槍"},
	 {"물", "水"},
	 {"치료", "治療"},
	 {"폭발", "爆発"},
	 {"손톱", "爪"},
	 {"화살", "矢"},
	 {"신성", "神聖"},
	 {"소생", "蘇生"},
	 {"전격", "雷"},
	 {"채찍", "鞭"},
	 {"바람", "風"},
	 {"마비", "麻痺"}
	};

	RTP_TABLE_2003["battlecharset"] = {
	 // Official English translation names
	 {"female elf a", "エルフ女a"},
	 {"female elf b", "エルフ女b"},
	 {"male elf a", "エルフ男a"},
	 {"male elf b", "エルフ男b"},
	 {"chinese woman a", "中華女a"},
	 {"chinese woman b", "中華女b"},
	 {"chinese man a", "中華男a"},
	 {"chinese man b", "中華男b"},
	 {"samurai a", "侍a"},
	 {"samurai b", "侍b"},
	 {"female monk a", "僧侶女a"},
	 {"female monk b", "僧侶女b"},
	 {"male monk a", "僧侶男a"},
	 {"male monk b", "僧侶男b"},
	 {"female hero a", "勇者女a"},
	 {"female hero b", "勇者女b"},
	 {"male hero a", "勇者男a"},
	 {"male hero b", "勇者男b"},
	 {"woman1 a", "女性１a"},
	 {"woman1 b", "女性１b"},
	 {"woman2 a", "女性２a"},
	 {"woman2 b", "女性２b"},
	 {"woman3 a", "女性３a"},
	 {"woman3 b", "女性３b"},
	 {"woman4 a", "女性４a"},
	 {"woman4 b", "女性４b"},
	 {"woman5 a", "女性５a"},
	 {"woman5 b", "女性５b"},
	 {"female ninja a", "忍者女a"},
	 {"female ninja b", "忍者女b"},
	 {"male ninja a", "忍者男a"},
	 {"male ninja b", "忍者男b"},
	 {"female warrior a", "戦士女a"},
	 {"female warrior b", "戦士女b"},
	 {"male warrior a", "戦士男a"},
	 {"male warrior b", "戦士男b"},
	 {"female fighter a", "格闘家女a"},
	 {"female fighter b", "格闘家女b"},
	 {"male fighter a", "格闘家男a"},
	 {"male fighter b", "格闘家男b"},
	 {"female pirate a", "海賊女a"},
	 {"female pirate b", "海賊女b"},
	 {"male pirate a", "海賊男a"},
	 {"male pirate b", "海賊男b"},
	 {"man1 a", "男性１a"},
	 {"man1 b", "男性１b"},
	 {"man2 a", "男性２a"},
	 {"man2 b", "男性２b"},
	 {"man3 a", "男性３a"},
	 {"man3 b", "男性３b"},
	 {"man4 a", "男性４a"},
	 {"man4 b", "男性４b"},
	 {"man5 a", "男性５a"},
	 {"man5 b", "男性５b"},
	 {"female bandit a", "盗賊女a"},
	 {"female bandit b", "盗賊女b"},
	 {"male bandit a", "盗賊男a"},
	 {"male bandit b", "盗賊男b"},
	 {"armored warror a", "鎧武者a"},
	 {"armored warror b", "鎧武者b"},
	 {"female mage a", "魔術師女a"},
	 {"female mage b", "魔術師女b"},
	 {"male mage a", "魔術師男a"},
	 {"male mage b", "魔術師男b"},

	 // RPG Advocate English translation names
	 {"elf-f-1", "エルフ女a"},
	 {"elf-f-2", "エルフ女b"},
	 {"elf-m-1", "エルフ男a"},
	 {"elf-m-2", "エルフ男b"},
	 {"chinese-f-1", "中華女a"},
	 {"chinese-f-2", "中華女b"},
	 {"chinese-m-1", "中華男a"},
	 {"chinese-m-2", "中華男b"},
	 {"samurai1", "侍a"},
	 {"samurai2", "侍b"},
	 {"priestess1", "僧侶女a"},
	 {"priestess2", "僧侶女b"},
	 {"priest1", "僧侶男a"},
	 {"priest2", "僧侶男b"},
	 {"hero-f-1", "勇者女a"},
	 {"hero-f-2", "勇者女b"},
	 {"hero-m-1", "勇者男a"},
	 {"hero-m-2", "勇者男b"},
	 {"woman1-1", "女性１a"},
	 {"woman1-2", "女性１b"},
	 {"woman2-1", "女性２a"},
	 {"woman2-2", "女性２b"},
	 {"woman3-1", "女性３a"},
	 {"woman3-2", "女性３b"},
	 {"woman4-1", "女性４a"},
	 {"woman4-2", "女性４b"},
	 {"woman5-1", "女性５a"},
	 {"woman5-2", "女性５b"},
	 {"ninja-f-1", "忍者女a"},
	 {"ninja-f-2", "忍者女b"},
	 {"ninja-m-1", "忍者男a"},
	 {"ninja-m-2", "忍者男b"},
	 {"soldier-f-1", "戦士女a"},
	 {"soldier-f-2", "戦士女b"},
	 {"soldier-m-1", "戦士男a"},
	 {"solider-m-2", "戦士男b"},
	 {"monk-f-1", "格闘家女a"},
	 {"monk-f-2", "格闘家女b"},
	 {"monk-m-1", "格闘家男a"},
	 {"monk-m-2", "格闘家男b"},
	 {"pirate-f-1", "海賊女a"},
	 {"pirate-f-2", "海賊女b"},
	 {"pirate-m-1", "海賊男a"},
	 {"pirate-m-2", "海賊男b"},
	 {"man1-1", "男性１a"},
	 {"man1-2", "男性１b"},
	 {"man2-1", "男性２a"},
	 {"man2-2", "男性２b"},
	 {"man3-1", "男性３a"},
	 {"man3-2", "男性３b"},
	 {"man4-1", "男性４a"},
	 {"man4-2", "男性４b"},
	 {"man5-1", "男性５a"},
	 {"man5-2", "男性５b"},
	 {"thief-f-1", "盗賊女a"},
	 {"thief-f-2", "盗賊女b"},
	 {"thief-m-1", "盗賊男a"},
	 {"thief-m-2", "盗賊男b"},
	 {"armor1", "鎧武者a"},
	 {"armor2", "鎧武者b"},
	 {"mage-f-1", "魔術師女a"},
	 {"mage-f-2", "魔術師女b"},
	 {"mage-m-1", "魔術師男a"},
	 {"mage-m-2", "魔術師男b"},

	 // Unknown English translation names used by Spanish games
	 {"elfwomana", "エルフ女a"},
	 {"elfwomanb", "エルフ女b"},
	 {"elfmana", "エルフ男a"},
	 {"elfmanb", "エルフ男b"},
	 {"chinesewomana", "中華女a"},
	 {"chinesewomanb", "中華女b"},
	 {"chinesemana", "中華男a"},
	 {"chinesemanb", "中華男b"},
	 {"samuraia", "侍a"},
	 {"samuraib", "侍b"},
	 {"monkwomana", "僧侶女a"},
	 {"monkwomanb", "僧侶女b"},
	 {"monkmana", "僧侶男a"},
	 {"monkmanb", "僧侶男b"},
	 {"herowomana", "勇者女a"},
	 {"herowomanb", "勇者女b"},
	 {"heromana", "勇者男a"},
	 {"heromanb", "勇者男b"},
	 {"womanépa", "女性１a"},
	 {"womanépb", "女性１b"},
	 {"womanéqa", "女性２a"},
	 {"womanéqb", "女性２b"},
	 {"womanéra", "女性３a"},
	 {"womanérb", "女性３b"},
	 {"womanésa", "女性４a"},
	 {"womanésb", "女性４b"},
	 {"womanéta", "女性５a"},
	 {"womanétb", "女性５b"},
	 {"ninjawomana", "忍者女a"},
	 {"ninjawomanb", "忍者女b"},
	 {"ninjamana", "忍者男a"},
	 {"ninjamanb", "忍者男b"},
	 {"soldierwomana", "戦士女a"},
	 {"soldierwomanb", "戦士女b"},
	 {"soldiermana", "戦士男a"},
	 {"soldiermanb", "戦士男b"},
	 {"grapplehousewomana", "格闘家女a"},
	 {"grapplehousewomanb", "格闘家女b"},
	 {"grapplehousemana", "格闘家男a"},
	 {"grapplehousemanb", "格闘家男b"},
	 {"piratewomana", "海賊女a"},
	 {"piratewomanb", "海賊女b"},
	 {"piratemana", "海賊男a"},
	 {"pirateb", "海賊男b"},
	 {"manépa", "男性１a"},
	 {"manépb", "男性１b"},
	 {"manéqa", "男性２a"},
	 {"manéqb", "男性２b"},
	 {"manéra", "男性３a"},
	 {"manérb", "男性３b"},
	 {"manésa", "男性４a"},
	 {"manésb", "男性４b"},
	 {"manéta", "男性５a"},
	 {"manétb", "男性５b"},
	 {"thiefwomana", "盗賊女a"},
	 {"thiefwomanb", "盗賊女b"},
	 {"thiefmana", "盗賊男a"},
	 {"thiefmanb", "盗賊男b"},
	 {"armourwarriora", "鎧武者a"},
	 {"armourwarriorb", "鎧武者b"},
	 {"magicteacherwomana", "魔術師女a"},
	 {"magicteacherwomanb", "魔術師女b"},
	 {"magicteachermana", "魔術師男a"},
	 {"magicteachermanb", "魔術師男b"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"tuanaa", "エルフ女a"},
	 {"tanab", "エルフ女b"},
	 {"temmada", "エルフ男a"},
	 {"temmadb", "エルフ男b"},
	 {"chuzaa", "中華女a"},
	 {"chuzab", "中華女b"},
	 {"chinga", "中華男a"},
	 {"chingb", "中華男b"},
	 {"garrea", "侍a"},
	 {"garreb", "侍b"},
	 {"kloria", "僧侶女a"},
	 {"klorib", "僧侶女b"},
	 {"siossa", "僧侶男a"},
	 {"siossb", "僧侶男b"},
	 {"noddaa", "勇者女a"},
	 {"noddab", "勇者女b"},
	 {"jemmona", "勇者男a"},
	 {"jemmonb", "勇者男b"},
	 {"cletoa", "女性１a"},
	 {"cletob", "女性１b"},
	 {"cikuaa", "女性２a"},
	 {"jikuab", "女性２b"},
	 {"irregiaa", "女性３a"},
	 {"irregiab", "女性３b"},
	 {"nysmaa", "女性４a"},
	 {"nysmab", "女性４b"},
	 {"beruaa", "女性５a"},
	 {"beruab", "女性５b"},
	 {"ginnya", "忍者女a"},
	 {"ginnyb", "忍者女b"},
	 {"xeoda", "忍者男a"},
	 {"xeodb", "忍者男b"},
	 {"eljeaa", "戦士女a"},
	 {"eljeab", "戦士女b"},
	 {"raglea", "戦士男a"},
	 {"ragleb", "戦士男b"},
	 {"phesaa", "格闘家女a"},
	 {"phesab", "格闘家女b"},
	 {"rasnena", "格闘家男a"},
	 {"rasnenb", "格闘家男b"},
	 {"rennaa", "海賊女a"},
	 {"rennab", "海賊女b"},
	 {"goxana", "海賊男a"},
	 {"goxanb", "海賊男b"},
	 {"jidada", "男性１a"},
	 {"jidadb", "男性１b"},
	 {"mjitta", "男性２a"},
	 {"mjittb", "男性２b"},
	 {"chuaza", "男性３a"},
	 {"chuazb", "男性３b"},
	 {"shella", "男性４a"},
	 {"shellb", "男性４b"},
	 {"frossa", "男性５a"},
	 {"frossb", "男性５b"},
	 {"otipaa", "盗賊女a"},
	 {"otipab", "盗賊女b"},
	 {"unnona", "盗賊男a"},
	 {"unnonb", "盗賊男b"},
	 {"joegoa", "鎧武者a"},
	 {"joegob", "鎧武者b"},
	 {"ljitia", "魔術師女a"},
	 {"ljitib", "魔術師女b"},
	 {"rivraa", "魔術師男a"},
	 {"rivrab", "魔術師男b"},

	 // Korean RTP
	 {"사무라이a", "侍a"},
	 {"엘프女 a", "エルフ女a"},
	 {"여성１a", "女性１a"},
	 {"여성５a", "女性５a"},
	 {"여성４a", "女性４a"},
	 {"여성２a", "女性２a"},
	 {"여성３a", "女性３a"},
	 {"해적女a", "海賊女a"},
	 {"남성４a", "男性４a"},
	 {"남성３a", "男性３a"},
	 {"남성２a", "男性２a"},
	 {"남성５a", "男性５a"},
	 {"남성１a", "男性１a"},
	 {"갑옷무사a", "鎧武者a"},
	 {"사무라이b", "侍b"},
	 {"엘프女 b", "エルフ女b"},
	 {"여성４b", "女性４b"},
	 {"여성３b", "女性３b"},
	 {"여성１b", "女性１b"},
	 {"여성２b", "女性２b"},
	 {"여성５b", "女性５b"},
	 {"해적女b", "海賊女b"},
	 {"남성１b", "男性１b"},
	 {"남성２b", "男性２b"},
	 {"남성５b", "男性５b"},
	 {"남성４b", "男性４b"},
	 {"남성３b", "男性３b"},
	 {"갑옷무사b", "鎧武者b"},
	 {"중화女a", "中華女a"},
	 {"승려女a", "僧侶女a"},
	 {"용자女a", "勇者女a"},
	 {"닌자女a", "忍者女a"},
	 {"전사女a", "戦士女a"},
	 {"격투가女a", "格闘家女a"},
	 {"도적女a", "盗賊女a"},
	 {"마술사女a", "魔術師女a"},
	 {"중화女b", "中華女b"},
	 {"승려女b", "僧侶女b"},
	 {"용자女b", "勇者女b"},
	 {"닌자女b", "忍者女b"},
	 {"전사女b", "戦士女b"},
	 {"격투가女b", "格闘家女b"},
	 {"도적女b", "盗賊女b"},
	 {"마술사女b", "魔術師女b"},
	 {"중화男a", "中華男a"},
	 {"승려男a", "僧侶男a"},
	 {"용자男a", "勇者男a"},
	 {"닌자男a", "忍者男a"},
	 {"전사男a", "戦士男a"},
	 {"격투가男a", "格闘家男a"},
	 {"해적男a", "海賊男a"},
	 {"엘프男 a", "エルフ男a"},
	 {"도적男a", "盗賊男a"},
	 {"마술사男a", "魔術師男a"},
	 {"중화男b", "中華男b"},
	 {"승려男b", "僧侶男b"},
	 {"용자男b", "勇者男b"},
	 {"닌자男b", "忍者男b"},
	 {"전사男b", "戦士男b"},
	 {"격투가男b", "格闘家男b"},
	 {"해적男b", "海賊男b"},
	 {"엘프男 b", "エルフ男b"},
	 {"도적男b", "盗賊男b"},
	 {"마술사男b", "魔術師男b"}
	};

	RTP_TABLE_2003["battleweapon"] = {
	 // Official English translation names
	 {"weapon", "武器"},

	 // RPG Advocate English translation name
	 {"weapons", "武器"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"standart", "武器"},

	 // Korean RTP
	 {"무기", "武器"}
	};

	RTP_TABLE_2003["charset"] = {
	 // Official English translation names
	 {"object1", "オブジェクト1"},
	 {"object2", "オブジェクト2"},
	 {"monster1", "モンスター1"},
	 {"monster2", "モンスター2"},
	 {"people1", "一般1"},
	 {"people2", "一般2"},
	 {"people3", "一般3"},
	 {"people4", "一般4"},
	 {"people5", "一般5"},
	 {"actor1", "主人公1"},
	 {"actor2", "主人公2"},
	 {"actor3", "主人公3"},
	 {"actor4", "主人公4"},
	 {"vehicles", "乗り物"},
	 {"animal", "動物"},

	 // RPG Advocate English translation names
	 {"char1", "一般1"},
	 {"char2", "一般2"},
	 {"char3", "一般3"},
	 {"char4", "一般4"},
	 {"char5", "一般5"},
	 {"hero1", "主人公1"},
	 {"hero2", "主人公2"},
	 {"hero3", "主人公3"},
	 {"hero4", "主人公4"},
	 {"vehicle", "乗り物"},

	 // Unknown English translation names used by Spanish games
	 {"general1", "一般1"},
	 {"general2", "一般2"},
	 {"general3", "一般3"},
	 {"general4", "一般4"},
	 {"general5", "一般5"},
	 {"protagonist1", "主人公1"},
	 {"protagonist2", "主人公2"},
	 {"protagonist3", "主人公3"},
	 {"protagonist4", "主人公4"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"objects1", "オブジェクト1"},
	 {"objects2", "オブジェクト2"},
	 {"monsters1", "モンスター1"},
	 {"monsters2", "モンスター2"},
	 {"chara1", "主人公1"},
	 {"chara2", "主人公2"},
	 {"chara3", "主人公3"},
	 {"chara4", "主人公4"},
	 {"animals", "動物"},

	 // 2000 RTP names not overwritten by Vlad Kovnerov's installation
	 {"people7", "一般2"},

	 // Orphaned Don Miguel's 2000 RTP extras pointing to nearest match
	 {"chubby1", "一般3"},
	 {"chubby2", "一般2"},
	 {"crown1", "主人公4"},
	 {"crown2", "モンスター2"},
	 {"crown3", "モンスター1"},
	 {"crown4", "動物"},
	 {"crown5", "一般5"},
	 {"crown6", "モンスター1"},
	 {"crown7", "動物"},
	 {"future1", "一般1"},
	 {"future2", "一般4"},
	 {"future3", "一般5"},
	 {"men1", "一般4"},
	 {"women1", "一般5"},

	 //Korean RTP
	 {"오브젝트1", "オブジェクト1"},
	 {"몬스터1", "モンスター1"},
	 {"일반1", "一般1"},
	 {"주인공1", "主人公1"},
	 {"오브젝트2", "オブジェクト2"},
	 {"몬스터2", "モンスター2"},
	 {"일반2", "一般2"},
	 {"주인공2", "主人公2"},
	 {"일반3", "一般3"},
	 {"주인공3", "主人公3"},
	 {"일반4", "一般4"},
	 {"주인공4", "主人公4"},
	 {"일반5", "一般5"},
	 {"탈것", "乗り物"},
	 {"동물", "動物"}
	};

	RTP_TABLE_2003["chipset"] = {
	 // Official English translation names
	 {"dungeon", "ダンジョン"},
	 {"interior", "内装"},
	 {"world", "基本"},
	 {"exterior", "外観"},
	 {"ship", "船"},

	 // RPG Advocate English translation names
	 {"building", "内装"},
	 {"main", "基本"},
	 {"town", "外観"},

	 // Unknown English translation names used by Spanish games
	 {"donjohn", "ダンジョン"},
	 {"basic", "基本"},
	 {"appearance", "外観"},
	 {"boat", "船"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"internal1", "ダンジョン"},
	 {"internal2", "内装"},
	 {"village", "外観"},

	 // 2000 RTP names not overwritten by Vlad Kovnerov's installation
	 {"inner", "内装"},
	 {"basis", "基本"},
	 {"outline", "外観"},

	 // Orphaned Don Miguel's 2000 RTP extras pointing to nearest match
	 {"chipset1", "ダンジョン"},
	 {"chipset2", "内装"},
	 {"chipset3", "船"},

	 // Korean RTP
	 {"던젼", "ダンジョン"},
	 {"내부", "内装"},
	 {"기본", "基本"},
	 {"외견", "外観"},
	 {"배", "船"}
	};

	RTP_TABLE_2003["faceset"] = {
	 // Official English translation names
	 {"monster", "モンスター"},
	 {"people1", "一般1"},
	 {"people2", "一般2"},
	 {"actor1", "主人公1"},
	 {"actor2", "主人公2"},

	 // RPG Advocate English translation names
	 {"faces1", "一般1"},
	 {"faces2", "一般2"},
	 {"hero1", "主人公1"},
	 {"hero2", "主人公2"},

	 // Unknown English translation names used by Spanish games
	 {"general1", "一般1"},
	 {"general2", "一般2"},
	 {"protagonist1", "主人公1"},
	 {"protagonist2", "主人公2"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"monsters", "モンスター"},
	 {"people", "一般1"},
	 {"peopleanimal", "一般2"},
	 {"face1", "主人公1"},
	 {"face2", "主人公2"},

	 // 2000 RTP names not overwritten by Vlad Kovnerov's installation
	 {"people1", "一般1"},
	 {"people2", "一般2"},
	 {"chara1", "主人公1"},
	 {"chara2", "主人公2"},

	 // Korean RTP
	 {"일반1", "一般1"},
	 {"일반2", "一般2"},
	 {"주인공1", "主人公1"},
	 {"주인공2", "主人公2"},
	 {"몬스터", "モンスター"}
	};

	RTP_TABLE_2003["gameover"] = {
	 // Official English translation names
	 {"game over", "ゲームオーバー"},

	 // RPG Advocate English translation names
	 {"gameover", "ゲームオーバー"},

	 // Korean RTP
	 {"게임오버", "ゲームオーバー"}
	};

	RTP_TABLE_2003["monster"] = {
	 // Official English translation names
	 {"ahriman", "アーリマン"},
	 {"asura", "アスラ"},
	 {"anaconda", "アナコンダ"},
	 {"alligator", "アリゲーター"},
	 {"undead knight", "アンデッドナイト"},
	 {"ifreet", "イフリート"},
	 {"imp", "インプ"},
	 {"vampire", "ヴァンパイア"},
	 {"ouroboros", "ウロボロス"},
	 {"elf", "エルフ"},
	 {"ogre", "オーガ"},
	 {"orc", "オーク"},
	 {"odin", "オーディン"},
	 {"octopus", "オクトパス"},
	 {"gargoyle", "ガーゴイル"},
	 {"carbuncle", "カーバンクル"},
	 {"carmilla", "カーミラ"},
	 {"kappa", "カッパ"},
	 {"catoblepas", "カトブレパス"},
	 {"garuda", "ガルーダ"},
	 {"chimera", "キメラ"},
	 {"ghoul", "グール"},
	 {"kraken", "クラーケン"},
	 {"crab", "クラブ"},
	 {"griffon", "グリフォン"},
	 {"grell", "グレル"},
	 {"crawler", "クロウラー"},
	 {"gazer", "ゲイザー"},
	 {"quetzalcoatl", "ケツアルクアトル"},
	 {"cait sith", "ケットシー"},
	 {"cerberus", "ケルベロス"},
	 {"centaur", "ケンタウロス"},
	 {"gorgon", "ゴーゴン"},
	 {"ghost", "ゴースト"},
	 {"golem", "ゴーレム"},
	 {"cockatorice", "コカトリス"},
	 {"goblin", "ゴブリン"},
	 {"kobold", "コボルト"},
	 {"cyclops", "サイクロプス"},
	 {"satan", "サタナエル"},
	 {"sahagin", "サハギン"},
	 {"salamander", "サラマンダー"},
	 {"shark", "シャーク"},
	 {"giant", "ジャイアント"},
	 {"jack-o-lantern", "ジャック・オー・ランタン"},
	 {"shadow", "シャドウ"},
	 {"sylph", "シルフ"},
	 {"scylla", "スキュラ"},
	 {"skeleton", "スケルトン"},
	 {"scorpion", "スコーピオン"},
	 {"snake", "スネーク"},
	 {"spirit", "スピリッツ"},
	 {"sphinx", "スフィンクス"},
	 {"spectre", "スペクター"},
	 {"slime", "スライム"},
	 {"siren", "セイレーン"},
	 {"seraphim", "セラフィム"},
	 {"centipede", "センチピード"},
	 {"sorcerer", "ソーサラー"},
	 {"zombie", "ゾンビ"},
	 {"dark elf", "ダークエルフ"},
	 {"dark knight", "ダークナイト"},
	 {"titan", "タイタン"},
	 {"tarantula", "タランチュラ"},
	 {"tiamat", "ティアマット"},
	 {"demon", "デーモン"},
	 {"toad", "トード"},
	 {"dragon", "ドラゴン"},
	 {"dragon knight", "ドラゴンナイト"},
	 {"treant", "トレント"},
	 {"troll", "トロール"},
	 {"necromancer", "ネクロマンサー"},
	 {"nepenthes", "ネペンテス"},
	 {"berserker", "バーサーカー"},
	 {"harpy", "ハーピー"},
	 {"basilisk", "バジリスク"},
	 {"bat", "バット"},
	 {"bahamut", "バハムート"},
	 {"parasite", "パラサイト"},
	 {"big foot", "ビッグフット"},
	 {"hydra", "ヒュドラ"},
	 {"phoenix", "フェニックス"},
	 {"fenrir", "フェンリル"},
	 {"behemoth", "ベヒーモス"},
	 {"hornet", "ホーネット"},
	 {"manticore", "マンティコア"},
	 {"mantis", "マンティス"},
	 {"mammoth", "マンモス"},
	 {"mummy", "ミイラ男"},
	 {"midgardsormr", "ミドガルズオルム"},
	 {"minotaur", "ミノタウロス"},
	 {"mimic", "ミミック"},
	 {"medusa", "メデューサ"},
	 {"unicorn", "ユニコーン"},
	 {"lakshmi", "ラクシュミ"},
	 {"lamia", "ラミア"},
	 {"leviathan", "リヴァイアサン"},
	 {"lizard", "リザード"},
	 {"lizardman", "リザードマン"},
	 {"lich", "リッチ"},
	 {"lilith", "リリス"},
	 {"wraith", "レイス"},
	 {"remora", "レモラ"},
	 {"werewolf", "ワーウルフ"},
	 {"worm", "ワーム"},
	 {"wight", "ワイト"},
	 {"wyvern", "ワイバーン"},
	 {"kyuubi", "九尾の狐"},
	 {"suzaku", "朱雀"},
	 {"genbu", "玄武"},
	 {"byakko", "白虎"},
	 {"horse", "馬"},
	 {"oni", "鬼"},
	 {"kirin", "麒麟"},
	 {"ryuu", "龍"},

	 // RPG Advocate English translation names
	 {"ariman", "アーリマン"},
	 {"u-knight", "アンデッドナイト"},
	 {"efreet", "イフリート"},
	 {"oroboros", "ウロボロス"},
	 {"cojurer", "カーミラ"},
	 {"cancer", "クラブ"},
	 {"deathgaze", "ゲイザー"},
	 {"quezal", "ケツアルクアトル"},
	 {"caitsith", "ケットシー"},
	 {"cockatrice", "コカトリス"},
	 {"jack", "ジャック・オー・ランタン"},
	 {"specter", "スペクター"},
	 {"seraph", "セラフィム"},
	 {"darkelf", "ダークエルフ"},
	 {"darkknight", "ダークナイト"},
	 {"spider", "タランチュラ"},
	 {"dragonknight", "ドラゴンナイト"},
	 {"nepenthe", "ネペンテス"},
	 {"bigfoot", "ビッグフット"},
	 {"midgard-serp", "ミドガルズオルム"},
	 {"rakashimi", "ラクシュミ"},
	 {"lillith", "リリス"},
	 {"ninetail", "九尾の狐"},
	 {"redsparrow", "朱雀"},
	 {"blackturtle", "玄武"},
	 {"whitetiger", "白虎"},
	 {"nightmare", "馬"},
	 {"ki-rin", "麒麟"},
	 {"bluedragon", "龍"},

	 // Unknown English translation names used by Spanish games
	 {"multiarmdemon", "アスラ"},
	 {"pimpskeleton", "アンデッドナイト"},
	 {"ifrit", "イフリート"},
	 {"littledemon", "インプ"},
	 {"dragon", "ウロボロス"},
	 {"auger", "オーガ"},
	 {"ork", "オーク"},
	 {"carbunkle", "カーバンクル"},
	 {"carmira", "カーミラ"},
	 {"raincoat", "カッパ"},
	 {"demonhorsething", "カトブレパス"},
	 {"seamonster", "クラーケン"},
	 {"griffin", "グリフォン"},
	 {"jellyfish", "グレル"},
	 {"crowera", "クロウラー"},
	 {"eyestalk", "ゲイザー"},
	 {"birdsnake", "ケツアルクアトル"},
	 {"ketsea", "ケットシー"},
	 {"cerebus", "ケルベロス"},
	 {"bull", "ゴーゴン"},
	 {"imp", "ゴブリン"},
	 {"giant", "サイクロプス"},
	 {"darkangel", "サタナエル"},
	 {"merman", "サハギン"},
	 {"giant-2", "ジャイアント"},
	 {"jackolantern", "ジャック・オー・ランタン"},
	 {"fairy", "シルフ"},
	 {"gorgon", "スキュラ"},
	 {"lostsoul", "スペクター"},
	 {"merangel", "セイレーン"},
	 {"angel", "セラフィム"},
	 {"catterpillar", "センチピード"},
	 {"wizard", "ソーサラー"},
	 {"daemon", "デーモン"},
	 {"frog", "トード"},
	 {"dragon-2", "ドラゴン"},
	 {"tree", "トレント"},
	 {"killerplant", "ネペンテス"},
	 {"barbarian", "バーサーカー"},
	 {"earwig", "バジリスク"},
	 {"lizarddemon", "バハムート"},
	 {"yeti", "ビッグフット"},
	 {"wolf", "フェンリル"},
	 {"bea", "ホーネット"},
	 {"monster", "マンティコア"},
	 {"preyingmantis", "マンティス"},
	 {"monster-2", "ミドガルズオルム"},
	 {"mystic", "ラクシュミ"},
	 {"gorgon-2", "ラミア"},
	 {"spectre", "レイス"},
	 {"flyingfish", "レモラ"},
	 {"yto", "ワイト"},
	 {"yburning", "ワイバーン"},
	 {"foxofninetails", "九尾の狐"},
	 {"monster-3", "玄武"},
	 {"ogre", "鬼"},
	 {"giraffe", "麒麟"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"maliciousflower", "アーリマン"},
	 {"weaponmaster", "アスラ"},
	 {"snake", "アナコンダ"},
	 {"crocodile", "アリゲーター"},
	 {"deadpirate", "アンデッドナイト"},
	 {"efrit", "イフリート"},
	 {"features", "インプ"},
	 {"levitan", "ウロボロス"},
	 {"archer", "エルフ"},
	 {"primitiveman", "オーガ"},
	 {"pigsoldier", "オーク"},
	 {"dangeroussoldier", "オーディン"},
	 {"rubyfox", "カーバンクル"},
	 {"murdererwoman", "カーミラ"},
	 {"morloc", "カッパ"},
	 {"curvebull", "カトブレパス"},
	 {"flyingwarrior", "ガルーダ"},
	 {"zombie", "グール"},
	 {"seabowl", "クラーケン"},
	 {"griphon", "グリフォン"},
	 {"robot", "グレル"},
	 {"worm", "クロウラー"},
	 {"eye", "ゲイザー"},
	 {"flyingworm", "ケツアルクアトル"},
	 {"eremite", "ケットシー"},
	 {"infernalbull", "ゴーゴン"},
	 {"witchphantom", "ゴースト"},
	 {"rooster", "コカトリス"},
	 {"littledemon", "ゴブリン"},
	 {"wolf", "コボルト"},
	 {"triton", "サハギン"},
	 {"burninglizard", "サラマンダー"},
	 {"cannibal", "ジャイアント"},
	 {"pumpkin", "ジャック・オー・ランタン"},
	 {"lostshadow", "シャドウ"},
	 {"medusa", "スキュラ"},
	 {"cancer", "スコーピオン"},
	 {"dangeroussnake", "スネーク"},
	 {"laughingspirit", "スピリッツ"},
	 {"sphynx", "スフィンクス"},
	 {"magicskull", "スペクター"},
	 {"flyingmermaid", "セイレーン"},
	 {"sephiroth", "セラフィム"},
	 {"multileg", "センチピード"},
	 {"magician", "ソーサラー"},
	 {"poisonzombie", "ゾンビ"},
	 {"fencer", "ダークエルフ"},
	 {"knight", "ダークナイト"},
	 {"many-domeddragon", "ティアマット"},
	 {"horngoat", "デーモン"},
	 {"bluedragon", "ドラゴン"},
	 {"dragonwarrior", "ドラゴンナイト"},
	 {"dendrid", "トレント"},
	 {"orc", "トロール"},
	 {"necromant", "ネクロマンサー"},
	 {"multirootflower", "ネペンテス"},
	 {"horned", "バジリスク"},
	 {"dragon", "バハムート"},
	 {"all-knowing", "パラサイト"},
	 {"many-domeduglycreature", "ヒュドラ"},
	 {"realwolf", "フェンリル"},
	 {"infernaldog", "ベヒーモス"},
	 {"bee", "ホーネット"},
	 {"crossedbeast", "マンティコア"},
	 {"insect", "マンティス"},
	 {"mamont", "マンモス"},
	 {"creepingcreature", "ミドガルズオルム"},
	 {"ogrechest", "ミミック"},
	 {"hypermedusa", "メデューサ"},
	 {"prophet", "ラクシュミ"},
	 {"mermaid", "ラミア"},
	 {"levitanwithahorn", "リヴァイアサン"},
	 {"monitorlizard", "リザード"},
	 {"lizardsoldier", "リザードマン"},
	 {"powerfulnecromant", "リッチ"},
	 {"multihandswarrior", "リリス"},
	 {"phantom", "レイス"},
	 {"sharpfish", "レモラ"},
	 {"werwolf", "ワーウルフ"},
	 {"toothworm", "ワーム"},
	 {"seizedsoldier", "ワイト"},
	 {"browndragon", "ワイバーン"},
	 {"magicfox", "九尾の狐"},
	 {"vainbird", "朱雀"},
	 {"turtlesnake", "玄武"},
	 {"polartiger", "白虎"},
	 {"darkhorse", "馬"},
	 {"fairytalehorse", "麒麟"},
	 {"longdragon", "龍"},

	 // 2000 RTP names not overwritten by Vlad Kovnerov's installation
	 {"hog", "オーク"},
	 {"darkrider", "トルーパー"},
	 {"aquamen", "マーマン"},
	 {"hellhound", "ケルベロス"},
	 {"wolfman", "コボルト"},
	 {"flyingdemon", "デーモン"},
	 {"greendragon1", "ドラゴン"},
	 {"oak", "トレント"},
	 {"lizardmen", "リザードマン"},
	 {"darkspirit", "リッチ"},
	 {"greendragon2", "龍"},

	 // Orphaned 2000 names pointing to nearest match
	 {"boy1", "インプ"},
	 {"girl2", "シルフ"},
	 {"boy3", "ソーサラー"},
	 {"girl4", "エルフ"},
	 {"man5", "ダークエルフ"},
	 {"girl6", "カーミラ"},
	 {"oldman7", "アンデッドナイト"},
	 {"granny", "ラクシュミ"},
	 {"warrior", "ワイト"},
	 {"redscorpion", "スコーピオン"},
	 {"princess", "ラクシュミ"},
	 {"ninja", "シャドウ"},
	 {"fish", "レモラ"},
	 {"hero1", "ダークエルフ"},
	 {"hero2", "カーミラ"},
	 {"samurai", "オーディン"},
	 {"death", "レイス"},
	 {"gnome", "オーガ"},
	 {"king", "タイタン"},
	 {"thief", "ケットシー"},
	 {"firescull", "スピリッツ"},
	 {"cloakdemon", "ネクロマンサー"},
	 {"witch1", "ソーサラー"},
	 {"witch2", "カーミラ"},

	 // Korean RTP
	 {"잭-오-랜턴", "ジャック・オー・ランタン"},
	 {"웜", "ワーム"},
	 {"데어 매트", "ティアマット"},
	 {"다크 엘프", "ダークエルフ"},
	 {"다크 나이트", "ダークナイト"},
	 {"실프", "シルフ"},
	 {"배트", "バット"},
	 {"크랩", "クラブ"},
	 {"엘프", "エルフ"},
	 {"구렐", "グレル"},
	 {"토드", "トード"},
	 {"구울", "グール"},
	 {"오거", "オーガ"},
	 {"리치", "リッチ"},
	 {"임프", "インプ"},
	 {"좀비", "ゾンビ"},
	 {"오크", "オーク"},
	 {"데몬", "デーモン"},
	 {"샤크", "シャーク"},
	 {"미믹", "ミミック"},
	 {"골렘", "ゴーレム"},
	 {"트롤", "トロール"},
	 {"하피", "ハーピー"},
	 {"고곤", "ゴーゴン"},
	 {"펜릴", "フェンリル"},
	 {"오딘", "オーディン"},
	 {"호넷", "ホーネット"},
	 {"빅풋", "ビッグフット"},
	 {"드래곤 나이트", "ドラゴンナイト"},
	 {"언데드 나이트", "アンデッドナイト"},
	 {"와이트", "ワイト"},
	 {"라미아", "ラミア"},
	 {"리리스", "リリス"},
	 {"카트바", "カッパ"},
	 {"레이스", "レイス"},
	 {"아수라", "アスラ"},
	 {"키메라", "キメラ"},
	 {"레모라", "レモラ"},
	 {"고블린", "ゴブリン"},
	 {"맘모스", "マンモス"},
	 {"드래곤", "ドラゴン"},
	 {"사하킨", "サハギン"},
	 {"타이탄", "タイタン"},
	 {"카미라", "カーミラ"},
	 {"스쿨라", "スキュラ"},
	 {"코볼트", "コボルト"},
	 {"슬라임", "スライム"},
	 {"고스트", "ゴースト"},
	 {"리자드", "リザード"},
	 {"게이져", "ゲイザー"},
	 {"히드라", "ヒュドラ"},
	 {"가루다", "ガルーダ"},
	 {"셰도우", "シャドウ"},
	 {"트렌트", "トレント"},
	 {"세이렌", "セイレーン"},
	 {"캐트시", "ケットシー"},
	 {"세라핌", "セラフィム"},
	 {"가고일", "ガーゴイル"},
	 {"그리폰", "グリフォン"},
	 {"와이번", "ワイバーン"},
	 {"스펙터", "スペクター"},
	 {"크라켄", "クラーケン"},
	 {"스켈톤", "スケルトン"},
	 {"워울프", "ワーウルフ"},
	 {"메두사", "メデューサ"},
	 {"아리맨", "アーリマン"},
	 {"소서러", "ソーサラー"},
	 {"유니콘", "ユニコーン"},
	 {"만티스", "マンティス"},
	 {"피닉스", "フェニックス"},
	 {"카방클", "カーバンクル"},
	 {"버저커", "バーサーカー"},
	 {"미드갈즈 오르무", "ミドガルズオルム"},
	 {"스테이크", "スネーク"},
	 {"아나콘다", "アナコンダ"},
	 {"쿠로우라", "クロウラー"},
	 {"사타나엘", "サタナエル"},
	 {"이프리트", "イフリート"},
	 {"라쿠슈미", "ラクシュミ"},
	 {"네벤테스", "ネペンテス"},
	 {"배히모스", "ベヒーモス"},
	 {"바하무트", "バハムート"},
	 {"옥토퍼스", "オクトパス"},
	 {"켈베로스", "ケルベロス"},
	 {"스피릿츠", "スピリッツ"},
	 {"스핑크스", "スフィンクス"},
	 {"타란튤라", "タランチュラ"},
	 {"사라멘더", "サラマンダー"},
	 {"스콜피온", "スコーピオン"},
	 {"센티피드", "センチピード"},
	 {"뱀파이어", "ヴァンパイア"},
	 {"리자드맨", "リザードマン"},
	 {"자이언트", "ジャイアント"},
	 {"만티코어", "マンティコア"},
	 {"우로보로스", "ウロボロス"},
	 {"페러사이트", "パラサイト"},
	 {"바실리크스", "バジリスク"},
	 {"코카트리스", "コカトリス"},
	 {"켄타우르스", "ケンタウロス"},
	 {"엘리게이터", "アリゲーター"},
	 {"사이클롭스", "サイクロプス"},
	 {"네크로맨서", "ネクロマンサー"},
	 {"리바이어던", "リヴァイアサン"},
	 {"케이시아르크 아토르", "ケツアルクアトル"},
	 {"카토부레바트", "カトブレパス"},
	 {"미노타우르스", "ミノタウロス"},
	 {"구미호", "九尾の狐"},
	 {"주작", "朱雀"},
	 {"현무", "玄武"},
	 {"백호", "白虎"},
	 {"말", "馬"},
	 {"기린", "麒麟"},
	 {"용", "龍"},
	 {"청룡", "龍"},
	 {"미이라 男", "ミイラ男"},
	 {"도깨비(鬼)", "鬼"}
	};

	RTP_TABLE_2003["music"] = {
	 // Official English translation names
	 {"2003healing spring", "2003いやしの泉"},
	 {"2003casino indulgence", "2003カジノ三昧"},
	 {"2003colosseum", "2003コロシアム"},
	 {"2003cyber city", "2003サイバーシティ"},
	 {"2003snow town", "2003スノータウン"},
	 {"2003panic", "2003パニック"},
	 {"2003maximum battle", "2003マキシマム・バトル"},
	 {"2003dream of striking it rich", "2003一獲千金の夢"},
	 {"2003adventurers", "2003冒険者たち"},
	 {"2003hero's return", "2003勇者の凱旋"},
	 {"2003ancient city", "2003古城"},
	 {"2003subterranean maze", "2003地下迷宮"},
	 {"2003dream forest", "2003夢幻の森"},
	 {"2003dreaminess", "2003夢見心地"},
	 {"2003free for all", "2003大混戦"},
	 {"2003wings to the sky", "2003大空への翼"},
	 {"2003cathedral", "2003大聖堂"},
	 {"2003fairy forest", "2003妖精の森"},
	 {"2003lonesome journey", "2003孤独な旅立ち"},
	 {"2003little army's march", "2003小さな兵隊のマーチ"},
	 {"2003village in the valley", "2003山あいの村"},
	 {"2003empire", "2003帝国〜エンパイア"},
	 {"2003young memories", "2003幼少の記憶"},
	 {"2003creeping darkness", "2003忍び寄る闇"},
	 {"2003in the eternal flow of time", "2003悠久の時の流れに"},
	 {"2003sorrow", "2003悲しみ"},
	 {"2003beginning of a war", "2003戦いの幕開け"},
	 {"2003church", "2003教会"},
	 {"2003sunnyvillage", "2003日だまりの村"},
	 {"2003darkaltar", "2003暗黒の祭壇"},
	 {"2003village of savages", "2003未開の集落"},
	 {"2003far eastern land", "2003極東の地"},
	 {"2003machine fortress", "2003機械要塞"},
	 {"2003ice labyrinth", "2003氷のラビリンス"},
	 {"2003final battleground", "2003決戦の地"},
	 {"2003deserted mansion", "2003無人の館"},
	 {"2003palace party", "2003王宮のパーティー"},
	 {"2003otherworldly corridor", "2003異次元回廊"},
	 {"2003waltz of blessings", "2003祝福ワルツ"},
	 {"2003steady breeze", "2003穏やかな風"},
	 {"2003tension", "2003緊迫"},
	 {"2003tepeated wars", "2003繰り返される戦い"},
	 {"2003city bustle", "2003街の賑わい"},
	 {"2003tavern", "2003街の酒場"},
	 {"2003deep memory", "2003記憶の彼方に"},
	 {"2003exploring ruins", "2003遺跡探索"},
	 {"2003battle with an evil god", "2003邪神との戦い"},
	 {"2003silence", "2003静寂"},
	 {"j2003horn", "j2003ホルン"},
	 {"jitem", "jアイテム"},
	 {"jjoke 1", "jギャグ1"},
	 {"jjoke 2", "jギャグ2"},
	 {"jfanfare 1", "jファンファーレ1"},
	 {"jfanfare 2", "jファンファーレ2"},
	 {"jfanfare 3", "jファンファーレ3"},
	 {"jfanfare 4", "jファンファーレ4"},
	 {"jfanfare 5", "jファンファーレ5"},
	 {"jfanfare 6", "jファンファーレ6"},
	 {"jinn 1", "j宿1"},
	 {"jinn 2", "j宿2"},
	 {"jend of battle 1", "j戦闘終了1"},
	 {"jend of battle 2", "j戦闘終了2"},
	 {"jend of battle 3", "j戦闘終了3"},
	 {"jend of battle 4", "j戦闘終了4"},
	 {"jdoubt", "j疑惑"},
	 {"jmystery", "j謎"},
	 {"se2003alarm", "se2003アラーム"},
	 {"se2003jungle", "se2003ジャングル"},
	 {"se2003bustle", "se2003雑踏"},
	 {"se2003wind", "se2003風"},
	 {"se2003bird", "se2003鳥"},
	 {"seearthquake", "se地震"},
	 {"sedownpour", "se大雨"},
	 {"seclock", "se時計"},
	 {"sesea", "se海"},
	 {"serain", "se雨"},
	 {"ending 1", "エンディング1"},
	 {"ending 2", "エンディング2"},
	 {"ending 3", "エンディング3"},
	 {"opening 1", "オープニング1"},
	 {"opening 2", "オープニング2"},
	 {"opening 3", "オープニング3"},
	 {"game over 1", "ゲームオーバー1"},
	 {"game over 2", "ゲームオーバー2"},
	 {"game over 3", "ゲームオーバー3"},
	 {"ghost town 1", "ゴーストタウン1"},
	 {"ghost town 2", "ゴーストタウン2"},
	 {"dungeon 1", "ダンジョン1"},
	 {"dungeon 2", "ダンジョン2"},
	 {"dungeon 3", "ダンジョン3"},
	 {"dungeon 4", "ダンジョン4"},
	 {"dungeon 5", "ダンジョン5"},
	 {"in a pinch", "ピンチ"},
	 {"field 1", "フィールド1"},
	 {"field 2", "フィールド2"},
	 {"field 3", "フィールド3"},
	 {"field 4", "フィールド4"},
	 {"boss 1", "ボス1"},
	 {"boss 2", "ボス2"},
	 {"boss 3", "ボス3"},
	 {"boss 4", "ボス4"},
	 {"vehicle 1", "乗り物1"},
	 {"vehicle 2", "乗り物2"},
	 {"vehicle 3", "乗り物3"},
	 {"parting 1", "別れ1"},
	 {"parting 2", "別れ2"},
	 {"hero 1", "勇者1"},
	 {"hero 2", "勇者2"},
	 {"animal", "動物"},
	 {"victory", "勝利"},
	 {"castle 1", "城1"},
	 {"castle 2", "城2"},
	 {"castle 3", "城3"},
	 {"tower 1", "塔1"},
	 {"tower 2", "塔2"},
	 {"tower 3", "塔3"},
	 {"fairy 1", "妖精1"},
	 {"fairy 2", "妖精2"},
	 {"repose 1", "安らぎ1"},
	 {"repose 2", "安らぎ2"},
	 {"repose 3", "安らぎ3"},
	 {"shop 1", "店1"},
	 {"shop 2", "店2"},
	 {"shop 3", "店3"},
	 {"wrath", "怒り"},
	 {"sorrow", "悲しみ"},
	 {"battle 1", "戦闘1"},
	 {"battle 2", "戦闘2"},
	 {"battle 3", "戦闘3"},
	 {"exploration", "探索"},
	 {"defeat", "敗北"},
	 {"church", "教会"},
	 {"lively market", "明るい市場"},
	 {"village 1", "村1"},
	 {"village 2", "村2"},
	 {"village 3", "村3"},
	 {"thief", "泥棒"},
	 {"liveliness", "活気"},
	 {"town 1", "町1"},
	 {"town 2", "町2"},
	 {"town 3", "町3"},
	 {"mystery 1", "神秘1"},
	 {"mystery 2", "神秘2"},
	 {"mystery 3", "神秘3"},
	 {"secret treasure", "秘宝"},
	 {"ship 1", "船1"},
	 {"ship 2", "船2"},
	 {"ship 3", "船3"},
	 {"trial", "試練"},
	 {"black market", "闇市"},
	 {"demon lord", "魔王"},

	 // RPG Advocate English translation names
	 {"spring", "2003いやしの泉"},
	 {"casino", "2003カジノ三昧"},
	 {"arena", "2003コロシアム"},
	 {"bustling-city", "2003サイバーシティ"},
	 {"snowtown", "2003スノータウン"},
	 {"panic", "2003パニック"},
	 {"fierce-battle", "2003マキシマム・バトル"},
	 {"jackpot", "2003一獲千金の夢"},
	 {"adventure", "2003冒険者たち"},
	 {"triumph", "2003勇者の凱旋"},
	 {"ancient-castle", "2003古城"},
	 {"labyrinth", "2003地下迷宮"},
	 {"forest", "2003夢幻の森"},
	 {"moonlight", "2003夢見心地"},
	 {"armyclash", "2003大混戦"},
	 {"airborne", "2003大空への翼"},
	 {"hallowed-halls", "2003大聖堂"},
	 {"fairies", "2003妖精の森"},
	 {"lonewolf", "2003孤独な旅立ち"},
	 {"march", "2003小さな兵隊のマーチ"},
	 {"mtn-village", "2003山あいの村"},
	 {"empire", "2003帝国〜エンパイア"},
	 {"memories", "2003幼少の記憶"},
	 {"foreboding", "2003忍び寄る闇"},
	 {"eternal", "2003悠久の時の流れに"},
	 {"sadness", "2003悲しみ"},
	 {"intro", "2003戦いの幕開け"},
	 {"church1", "2003教会"},
	 {"village4", "2003日だまりの村"},
	 {"evil-temple", "2003暗黒の祭壇"},
	 {"strangetown", "2003未開の集落"},
	 {"far-east", "2003極東の地"},
	 {"mecha-base", "2003機械要塞"},
	 {"icecave", "2003氷のラビリンス"},
	 {"showdown", "2003決戦の地"},
	 {"haunted", "2003無人の館"},
	 {"royal-ball", "2003王宮のパーティー"},
	 {"dimension", "2003異次元回廊"},
	 {"waltz", "2003祝福ワルツ"},
	 {"interlude", "2003穏やかな風"},
	 {"tension", "2003緊迫"},
	 {"endless-fight", "2003繰り返される戦い"},
	 {"town-square", "2003街の賑わい"},
	 {"bar", "2003街の酒場"},
	 {"memories2", "2003記憶の彼方に"},
	 {"ruins", "2003遺跡探索"},
	 {"godslayer", "2003邪神との戦い"},
	 {"calm", "2003静寂"},
	 {"horns", "j2003ホルン"},
	 {"item", "jアイテム"},
	 {"mischief1", "jギャグ1"},
	 {"mischief2", "jギャグ2"},
	 {"fanfare1", "jファンファーレ1"},
	 {"fanfare2", "jファンファーレ2"},
	 {"fanfare3", "jファンファーレ3"},
	 {"fanfare4", "jファンファーレ4"},
	 {"fanfare5", "jファンファーレ5"},
	 {"fanfare6", "jファンファーレ6"},
	 {"inn1", "j宿1"},
	 {"inn2", "j宿2"},
	 {"victory1", "j戦闘終了1"},
	 {"victory2", "j戦闘終了2"},
	 {"victory3", "j戦闘終了3"},
	 {"victory4", "j戦闘終了4"},
	 {"surprise", "j疑惑"},
	 {"riddle", "j謎"},
	 {"se-alarm", "se2003アラーム"},
	 {"se-jungle", "se2003ジャングル"},
	 {"se-crowd", "se2003雑踏"},
	 {"se-gale", "se2003風"},
	 {"se-bird", "se2003鳥"},
	 {"se-quake", "se地震"},
	 {"se-torrent", "se大雨"},
	 {"se-clock", "se時計"},
	 {"se-ocean", "se海"},
	 {"se-rain", "se雨"},
	 {"ending1", "エンディング1"},
	 {"ending2", "エンディング2"},
	 {"ending3", "エンディング3"},
	 {"opening1", "オープニング1"},
	 {"opening2", "オープニング2"},
	 {"opening3", "オープニング3"},
	 {"gameover1", "ゲームオーバー1"},
	 {"gameover2", "ゲームオーバー2"},
	 {"gameover3", "ゲームオーバー3"},
	 {"ghost-town1", "ゴーストタウン1"},
	 {"ghost-town2", "ゴーストタウン2"},
	 {"dungeon1", "ダンジョン1"},
	 {"dungeon2", "ダンジョン2"},
	 {"dungeon3", "ダンジョン3"},
	 {"dungeon4", "ダンジョン4"},
	 {"dungeon5", "ダンジョン5"},
	 {"tightspot", "ピンチ"},
	 {"field1", "フィールド1"},
	 {"field2", "フィールド2"},
	 {"field3", "フィールド3"},
	 {"field4", "フィールド4"},
	 {"boss1", "ボス1"},
	 {"boss2", "ボス2"},
	 {"boss3", "ボス3"},
	 {"boss4", "ボス4"},
	 {"vehicle1", "乗り物1"},
	 {"vehicle2", "乗り物2"},
	 {"vehicle3", "乗り物3"},
	 {"parting1", "別れ1"},
	 {"parting2", "別れ2"},
	 {"hero1", "勇者1"},
	 {"hero2", "勇者2"},
	 {"success", "勝利"},
	 {"castle1", "城1"},
	 {"castle2", "城2"},
	 {"castle3", "城3"},
	 {"tower1", "塔1"},
	 {"tower2", "塔2"},
	 {"tower3", "塔3"},
	 {"fairy1", "妖精1"},
	 {"fairy2", "妖精2"},
	 {"solace1", "安らぎ1"},
	 {"solace2", "安らぎ2"},
	 {"solace3", "安らぎ3"},
	 {"shop1", "店1"},
	 {"shop2", "店2"},
	 {"shop3", "店3"},
	 {"malice", "怒り"},
	 {"sad", "悲しみ"},
	 {"battle1", "戦闘1"},
	 {"battle2", "戦闘2"},
	 {"battle3", "戦闘3"},
	 {"explore", "探索"},
	 {"church2", "教会"},
	 {"bazaar", "明るい市場"},
	 {"village1", "村1"},
	 {"village2", "村2"},
	 {"village3", "村3"},
	 {"strength", "活気"},
	 {"town1", "町1"},
	 {"town2", "町2"},
	 {"town3", "町3"},
	 {"mystery1", "神秘1"},
	 {"mystery2", "神秘2"},
	 {"mystery3", "神秘3"},
	 {"treasure", "秘宝"},
	 {"boat1", "船1"},
	 {"boat2", "船2"},
	 {"boat3", "船3"},
	 {"ordeal", "試練"},
	 {"eviltown", "闇市"},
	 {"demonic", "魔王"},

	 // Unknown English translation names used by Spanish games
	 {"2003spring", "2003いやしの泉"},
	 {"2003casino", "2003カジノ三昧"},
	 {"2003colloseum", "2003コロシアム"},
	 {"2003rhinobarcity", "2003サイバーシティ"},
	 {"2003snowtown", "2003スノータウン"},
	 {"2003maximumsbattle", "2003マキシマム・バトル"},
	 {"2003dream-catchlotsofmoney", "2003一獲千金の夢"},
	 {"2003venturepeople", "2003冒険者たち"},
	 {"2003triumphalreturn", "2003勇者の凱旋"},
	 {"2003oldcastle", "2003古城"},
	 {"2003undergroundlabyrinth", "2003地下迷宮"},
	 {"2003forestoffantasy", "2003夢幻の森"},
	 {"2003mooniness", "2003夢見心地"},
	 {"2003largeconfoundcombat", "2003大混戦"},
	 {"2003wingtoskies", "2003大空への翼"},
	 {"2003largesaintlyhall", "2003大聖堂"},
	 {"2003fairyforest", "2003妖精の森"},
	 {"2003lonelyjourney", "2003孤独な旅立ち"},
	 {"2003marchofsmallsoldiers", "2003小さな兵隊のマーチ"},
	 {"2003villageofravines", "2003山あいの村"},
	 {"2003enpire", "2003帝国〜エンパイア"},
	 {"2003memoryofinfancy", "2003幼少の記憶"},
	 {"2003approachingdarkness", "2003忍び寄る闇"},
	 {"2003theeternalflow", "2003悠久の時の流れに"},
	 {"2003sorrow", "2003悲しみ"},
	 {"2003fightopening", "2003戦いの幕開け"},
	 {"2003church", "2003教会"},
	 {"2003villageball", "2003日だまりの村"},
	 {"2003altarofdarkness", "2003暗黒の祭壇"},
	 {"2003unexploredvillage", "2003未開の集落"},
	 {"2003fareasternarea", "2003極東の地"},
	 {"2003machinefortress", "2003機械要塞"},
	 {"2003icelabyrinth", "2003氷のラビリンス"},
	 {"2003areaofdecisivebattles", "2003決戦の地"},
	 {"2003unmannedmansion", "2003無人の館"},
	 {"2003courtparty", "2003王宮のパーティー"},
	 {"2003strangedimensionalcorridor", "2003異次元回廊"},
	 {"2003blessingwaltz", "2003祝福ワルツ"},
	 {"2003calmwind", "2003穏やかな風"},
	 {"2003tension", "2003緊迫"},
	 {"2003thefightwhichisrepeated", "2003繰り返される戦い"},
	 {"2003towncrowd", "2003街の賑わい"},
	 {"2003townbar", "2003街の酒場"},
	 {"2003onthefarsideofmemories", "2003記憶の彼方に"},
	 {"2003ruinssearch", "2003遺跡探索"},
	 {"2003wickedgodfight", "2003邪神との戦い"},
	 {"2003calmness", "2003静寂"},
	 {"jitem", "jアイテム"},
	 {"jgag1", "jギャグ1"},
	 {"jgag2", "jギャグ2"},
	 {"jfanfare1", "jファンファーレ1"},
	 {"jfanfare2", "jファンファーレ2"},
	 {"jfanfare3", "jファンファーレ3"},
	 {"jfanfare4", "jファンファーレ4"},
	 {"jfanfare5", "jファンファーレ5"},
	 {"jfanfare6", "jファンファーレ6"},
	 {"jinn1", "j宿1"},
	 {"jinn2", "j宿2"},
	 {"jaggressiveend1", "j戦闘終了1"},
	 {"jaggressiveend2", "j戦闘終了2"},
	 {"jaggressiveend3", "j戦闘終了3"},
	 {"jaggressiveend4", "j戦闘終了4"},
	 {"jdoubt", "j疑惑"},
	 {"jpuzzle", "j謎"},
	 {"se2003alarm", "se2003アラーム"},
	 {"se2003jungle", "se2003ジャングル"},
	 {"se2003bustle", "se2003雑踏"},
	 {"se2003wind", "se2003風"},
	 {"se2003bird", "se2003鳥"},
	 {"seearthquake", "se地震"},
	 {"seheavyrain", "se大雨"},
	 {"seclock", "se時計"},
	 {"sesea", "se海"},
	 {"serainy", "se雨"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"2003happiness", "2003いやしの泉"},
	 {"2003research", "2003カジノ三昧"},
	 {"2003piracy", "2003コロシアム"},
	 {"2003joyfulnews", "2003サイバーシティ"},
	 {"2003lullaby", "2003スノータウン"},
	 {"2003warning", "2003パニック"},
	 {"2003pursuit", "2003マキシマム・バトル"},
	 {"2003silentpleasure", "2003一獲千金の夢"},
	 {"2003farewell", "2003冒険者たち"},
	 {"2003bigpalace", "2003勇者の凱旋"},
	 {"2003glory", "2003古城"},
	 {"2003fast", "2003地下迷宮"},
	 {"2003worldsound", "2003夢幻の森"},
	 {"2003serenity", "2003夢見心地"},
	 {"2003gangster", "2003大混戦"},
	 {"2003fanfares", "2003大空への翼"},
	 {"2003grief", "2003大聖堂"},
	 {"2003workingmusic", "2003妖精の森"},
	 {"2003memoirs", "2003孤独な旅立ち"},
	 {"2003parade", "2003小さな兵隊のマーチ"},
	 {"2003eaststyle", "2003山あいの村"},
	 {"2003andagainpleasure", "2003帝国〜エンパイア"},
	 {"2003fairytale", "2003幼少の記憶"},
	 {"2003threat", "2003忍び寄る闇"},
	 {"2003calm", "2003悠久の時の流れに"},
	 {"2003calm2", "2003悲しみ"},
	 {"2003dangerousfog", "2003戦いの幕開け"},
	 {"2003church", "2003教会"},
	 {"2003farmer", "2003日だまりの村"},
	 {"2003globalfrustration", "2003暗黒の祭壇"},
	 {"2003witchsong", "2003未開の集落"},
	 {"2003flight", "2003極東の地"},
	 {"2003sadend", "2003機械要塞"},
	 {"2003drops", "2003氷のラビリンス"},
	 {"2003battlefield", "2003決戦の地"},
	 {"2003silentcrying", "2003無人の館"},
	 {"2003dance", "2003王宮のパーティー"},
	 {"2003fastbattle", "2003異次元回廊"},
	 {"2003waltz", "2003祝福ワルツ"},
	 {"2003summer", "2003穏やかな風"},
	 {"2003terribledream", "2003緊迫"},
	 {"2003fastbattle2", "2003繰り返される戦い"},
	 {"2003pleasure", "2003街の賑わい"},
	 {"2003travel", "2003街の酒場"},
	 {"2003morning", "2003記憶の彼方に"},
	 {"2003infiniteidea", "2003遺跡探索"},
	 {"2003chaos", "2003邪神との戦い"},
	 {"2003underwater", "2003静寂"},
	 {"2003win", "j2003ホルン"},
	 {"se2003ding", "se2003アラーム"},
	 {"se2003people", "se2003雑踏"},
	 {"se2003winter", "se2003風"},
	 {"se2003birds", "se2003鳥"},
	 {"serain2", "se大雨"},
	 {"serain", "se雨"},

	 // 2000 RTP names not overwritten by Vlad Kovnerov's installation
	 {"gag1", "jギャグ1"},
	 {"gag2", "jギャグ2"},
	 {"battleend1", "j戦闘終了1"},
	 {"battleend2", "j戦闘終了2"},
	 {"battleend3", "j戦闘終了3"},
	 {"battleend4", "j戦闘終了4"},
	 {"doubt", "j疑惑"},
	 {"gosttown1", "ゴーストタウン1"},
	 {"gosttown2", "ゴーストタウン2"},
	 {"crisis", "ピンチ"},
	 {"ride1", "乗り物1"},
	 {"ride2", "乗り物2"},
	 {"ride3", "乗り物3"},
	 {"farewell1", "別れ1"},
	 {"farewell2", "別れ2"},
	 {"get", "勝利"},
	 {"peace1", "安らぎ1"},
	 {"peace2", "安らぎ2"},
	 {"peace3", "安らぎ3"},
	 {"anger", "怒り"},
	 {"search", "探索"},
	 {"lose", "敗北"},
	 {"church", "教会"},
	 {"fiesta", "明るい市場"},
	 {"energy", "活気"},
	 {"ship1", "船1"},
	 {"ship2", "船2"},
	 {"ship3", "船3"},
	 {"dark", "闇市"},
	 {"devil", "魔王"},

	 // Korean RTP
	 {"고스트 타운1", "ゴーストタウン1"},
	 {"게임오버1", "ゲームオーバー1"},
	 {"지하감옥1", "ダンジョン1"},
	 {"오프닝1", "オープニング1"},
	 {"필드1", "フィールド1"},
	 {"보스1", "ボス1"},
	 {"끝1", "エンディング1"},
	 {"차량1", "乗り物1"},
	 {"이별1", "別れ1"},
	 {"용사1", "勇者1"},
	 {"성1", "城1"},
	 {"탑1", "塔1"},
	 {"요정1", "妖精1"},
	 {"편안해짐1", "安らぎ1"},
	 {"점1", "店1"},
	 {"전투1", "戦闘1"},
	 {"촌1", "村1"},
	 {"밭두둑1", "町1"},
	 {"신비1", "神秘1"},
	 {"배1", "船1"},
	 {"2003패닉", "2003パニック"},
	 {"2003스노우 타운", "2003スノータウン"},
	 {"2003사이버 시티", "2003サイバーシティ"},
	 {"2003맥시멈·전투", "2003マキシマム・バトル"},
	 {"2003콜로세움", "2003コロシアム"},
	 {"2003일획천금의 꿈", "2003一獲千金の夢"},
	 {"2003카지노", "2003カジノ三昧"},
	 {"2003여행자 서고", "2003冒険者たち"},
	 {"2003용사의 개선", "2003勇者の凱旋"},
	 {"2003고성", "2003古城"},
	 {"2003지하미궁", "2003地下迷宮"},
	 {"2003몽환의 숲", "2003夢幻の森"},
	 {"2003꿈을 꾸는 기분", "2003夢見心地"},
	 {"2003대혼전", "2003大混戦"},
	 {"2003대공의 날개", "2003大空への翼"},
	 {"2003대성당", "2003大聖堂"},
	 {"2003요정의 숲", "2003妖精の森"},
	 {"2003고독한 여행", "2003孤独な旅立ち"},
	 {"2003작은 군대의 행진곡", "2003小さな兵隊のマーチ"},
	 {"2003산골짜기 마을", "2003山あいの村"},
	 {"2003제국", "2003帝国～エンパイア"},
	 {"2003유소의 기억", "2003幼少の記憶"},
	 {"2003살며시 다가옴", "2003忍び寄る闇"},
	 {"2003유구의 흐름", "2003悠久の時の流れに"},
	 {"2003슬퍼하고", "2003悲しみ"},
	 {"2003싸움의 개막", "2003戦いの幕開け"},
	 {"2003교회", "2003教会"},
	 {"2003양지의 마을", "2003日だまりの村"},
	 {"2003암흑의 제단", "2003暗黒の祭壇"},
	 {"2003미개한 취락", "2003未開の集落"},
	 {"2003극동의 땅", "2003極東の地"},
	 {"2003기계 요새", "2003機械要塞"},
	 {"2003얼음의 래비런스", "2003氷のラビリンス"},
	 {"2003결전의 땅", "2003決戦の地"},
	 {"2003회복의 샘", "2003いやしの泉"},
	 {"2003무인 저택", "2003無人の館"},
	 {"2003왕궁의 파티", "2003王宮のパーティー"},
	 {"2003차원의 길", "2003異次元回廊"},
	 {"2003축복 왈츠", "2003祝福ワルツ"},
	 {"2003온화한 바람", "2003穏やかな風"},
	 {"2003긴박", "2003緊迫"},
	 {"2003반복된 싸움", "2003繰り返される戦い"},
	 {"2003거리의 북적임", "2003街の賑わい"},
	 {"2003거리의 술집", "2003街の酒場"},
	 {"2003기억의 저쪽에", "2003記憶の彼方に"},
	 {"2003유적 탐색", "2003遺跡探索"},
	 {"2003사신과의 싸움", "2003邪神との戦い"},
	 {"2003정적", "2003静寂"},
	 {"고스트 타운2", "ゴーストタウン2"},
	 {"게임오버2", "ゲームオーバー2"},
	 {"지하감옥2", "ダンジョン2"},
	 {"오프닝2", "オープニング2"},
	 {"필드2", "フィールド2"},
	 {"보스2", "ボス2"},
	 {"끝2", "エンディング2"},
	 {"차량2", "乗り物2"},
	 {"이별2", "別れ2"},
	 {"용사2", "勇者2"},
	 {"성2", "城2"},
	 {"탑2", "塔2"},
	 {"요정2", "妖精2"},
	 {"편안해짐2", "安らぎ2"},
	 {"점2", "店2"},
	 {"전투2", "戦闘2"},
	 {"촌2", "村2"},
	 {"밭두둑2", "町2"},
	 {"신비2", "神秘2"},
	 {"배2", "船2"},
	 {"게임오버3", "ゲームオーバー3"},
	 {"지하감옥3", "ダンジョン3"},
	 {"오프닝3", "オープニング3"},
	 {"필드3", "フィールド3"},
	 {"보스3", "ボス3"},
	 {"끝3", "エンディング3"},
	 {"차량3", "乗り物3"},
	 {"성3", "城3"},
	 {"탑3", "塔3"},
	 {"편안해짐3", "安らぎ3"},
	 {"점3", "店3"},
	 {"전투3", "戦闘3"},
	 {"촌3", "村3"},
	 {"밭두둑3", "町3"},
	 {"신비3", "神秘3"},
	 {"배3", "船3"},
	 {"지하감옥4", "ダンジョン4"},
	 {"필드4", "フィールド4"},
	 {"보스4", "ボス4"},
	 {"지하감옥5", "ダンジョン5"},
	 {"J팡파르1", "Jファンファーレ1"},
	 {"J개그1", "Jギャグ1"},
	 {"J숙소1", "J宿1"},
	 {"J전투종료1", "J戦闘終了1"},
	 {"J2003호른", "J2003ホルン"},
	 {"J팡파르2", "Jファンファーレ2"},
	 {"J개그2", "Jギャグ2"},
	 {"J숙소2", "J宿2"},
	 {"J전투종료2", "J戦闘終了2"},
	 {"J팡파르3", "Jファンファーレ3"},
	 {"J전투종료3", "J戦闘終了3"},
	 {"J팡파르4", "Jファンファーレ4"},
	 {"J전투종료4", "J戦闘終了4"},
	 {"J팡파르5", "Jファンファーレ5"},
	 {"J팡파르6", "Jファンファーレ6"},
	 {"J아이템", "Jアイテム"},
	 {"J의혹", "J疑惑"},
	 {"J수수께기", "J謎"},
	 {"핀치", "ピンチ"},
	 {"동물", "動物"},
	 {"승리", "勝利"},
	 {"화내다", "怒り"},
	 {"슬퍼하다", "悲しみ"},
	 {"탐색", "探索"},
	 {"패배", "敗北"},
	 {"교회", "教会"},
	 {"밝은 시장", "明るい市場"},
	 {"도둑", "泥棒"},
	 {"활기", "活気"},
	 {"바보", "秘宝"},
	 {"시련", "試練"},
	 {"암시장", "闇市"},
	 {"마왕", "魔王"},
	 {"SE2003알람", "SE2003アラーム"},
	 {"SE2003정글", "SE2003ジャングル"},
	 {"SE2003혼잡", "SE2003雑踏"},
	 {"SE2003바람", "SE2003風"},
	 {"SE2003새", "SE2003鳥"},
	 {"SE지진", "SE地震"},
	 {"SE호우", "SE大雨"},
	 {"SE시계", "SE時計"},
	 {"SE바다", "SE海"},
	 {"SE비", "SE雨"}
	};

	RTP_TABLE_2003["panorama"] = {
	 // Official English translation names
	 {"sunset1", "夕焼け1"},
	 {"sunset2", "夕焼け2"},
	 {"dawn1", "夜明け1"},
	 {"dawn2", "夜明け2"},
	 {"night sky1", "夜空1"},
	 {"night sky2", "夜空2"},
	 {"cosmos1", "宇宙"},
	 {"planet1", "惑星1"},
	 {"planet2", "惑星2"},
	 {"planet3", "惑星3"},
	 {"dimension rift", "異空間"},
	 {"sky1", "空1"},
	 {"sky2", "空2"},

	 // RPG Advocate English translation names
	 {"dusk1", "夕焼け1"},
	 {"dusk2", "夕焼け2"},
	 {"night1", "夜空1"},
	 {"night2", "夜空2"},
	 {"space", "宇宙"},
	 {"strange", "異空間"},

	 // Unknown English translation names used by Spanish games
	 {"eveningglow1", "夕焼け1"},
	 {"eveningglow2", "夕焼け2"},
	 {"nightempty1", "夜空1"},
	 {"nightempty2", "夜空2"},
	 {"planetary1", "惑星1"},
	 {"planetary2", "惑星2"},
	 {"planetary3", "惑星3"},
	 {"strangespacial", "異空間"},
	 {"empty1", "空1"},
	 {"empty2", "空2"},

	 // Russian RTP translation by Vlad Kovnerov
	 {"dawn1", "夕焼け1"},
	 {"dawn2", "夕焼け2"},
	 {"evening1", "夜明け1"},
	 {"evening2", "夜明け2"},
	 {"galaxy", "宇宙"},
	 {"weird", "異空間"},
	 {"morning1", "空1"},
	 {"morning2", "空2"},

	 // Korean RTP
	 {"석양1", "夕焼け1"},
	 {"새벽1", "夜明け1"},
	 {"밤하늘1", "夜空1"},
	 {"혹성1", "惑星1"},
	 {"하늘1", "空1"},
	 {"석양2", "夕焼け2"},
	 {"새벽2", "夜明け2"},
	 {"밤하늘2", "夜空2"},
	 {"혹성2", "惑星2"},
	 {"하늘2", "空2"},
	 {"혹성3", "惑星3"},
	 {"우주", "宇宙"},
	 {"이공간", "異空間"}
	};

	RTP_TABLE_2003["sound"] = {
	 // Official English translation names
	 {"item1", "アイテム1"},
	 {"item2", "アイテム2"},
	 {"chime1", "あたり1"},
	 {"chime2", "あたり2"},
	 {"buff", "アップ"},
	 {"dog", "イヌ"},
	 {"cow", "ウシ"},
	 {"horse", "ウマ"},
	 {"roar", "おたけび"},
	 {"cursor1", "カーソル1"},
	 {"cursor2", "カーソル2"},
	 {"glassshatter", "ガシャン"},
	 {"cancel1", "キャンセル1"},
	 {"cancel2", "キャンセル2"},
	 {"paralyze1", "しびれ1"},
	 {"paralyze2", "しびれ2"},
	 {"paralyze3", "しびれ3"},
	 {"jump1", "ジャンプ1"},
	 {"jump2", "ジャンプ2"},
	 {"shot1", "ショット1"},
	 {"shot2", "ショット2"},
	 {"shot3", "ショット3"},
	 {"switch1", "スイッチ1"},
	 {"switch2", "スイッチ2"},
	 {"debuff", "ダウン"},
	 {"damage1", "ダメージ1"},
	 {"damage2", "ダメージ2"},
	 {"teleport1", "テレポート1"},
	 {"teleport2", "テレポート2"},
	 {"tiger", "トラ"},
	 {"glare", "にらみ"},
	 {"chicken", "にわとり"},
	 {"cat", "ネコ"},
	 {"knock", "ノック"},
	 {"buzzer1", "はずれ1"},
	 {"buzzer2", "はずれ2"},
	 {"barrier", "バリア"},
	 {"sheep", "ひつじ"},
	 {"buzzer3", "ブザー1"},
	 {"buzzer4", "ブザー2"},
	 {"flash1", "フラッシュ1"},
	 {"flash2", "フラッシュ2"},
	 {"flash3", "フラッシュ3"},
	 {"breath", "ブレス"},
	 {"monster1", "モンスター1"},
	 {"monster2", "モンスター2"},
	 {"lion", "ライオン"},
	 {"ice1", "冷気1"},
	 {"ice2", "冷気2"},
	 {"ice3", "冷気3"},
	 {"ice4", "冷気4"},
	 {"ice5", "冷気5"},
	 {"ice6", "冷気6"},
	 {"ice7", "冷気7"},
	 {"ice8", "冷気8"},
	 {"ice9", "冷気9"},
	 {"ice10", "冷気10"},
	 {"ice11", "冷気11"},
	 {"sword1", "剣1"},
	 {"sword2", "剣2"},
	 {"sword3", "剣3"},
	 {"absorb1", "吸収1"},
	 {"absorb2", "吸収2"},
	 {"bite", "噛む"},
	 {"recovery1", "回復1"},
	 {"recovery2", "回復2"},
	 {"recovery3", "回復3"},
	 {"recovery4", "回復4"},
	 {"recovery5", "回復5"},
	 {"recovery6", "回復6"},
	 {"recovery7", "回復7"},
	 {"recovery8", "回復8"},
	 {"evade1", "回避1"},
	 {"evade2", "回避2"},
	 {"earthquake1", "地震1"},
	 {"earthquake2", "地震2"},
	 {"barrier1", "壁1"},
	 {"barrier2", "壁2"},
	 {"earth1", "大地1"},
	 {"earth2", "大地2"},
	 {"earth3", "大地3"},
	 {"earth4", "大地4"},
	 {"earth5", "大地5"},
	 {"earth6", "大地6"},
	 {"earth7", "大地7"},
	 {"earth8", "大地8"},
	 {"earth9", "大地9"},
	 {"earth10", "大地10"},
	 {"ensnare", "巻き付き"},
	 {"bow1", "弓1"},
	 {"bow2", "弓2"},
	 {"combat1", "戦闘1"},
	 {"combat2", "戦闘2"},
	 {"blow1", "打撃1"},
	 {"blow2", "打撃2"},
	 {"blow3", "打撃3"},
	 {"blow4", "打撃4"},
	 {"blow5", "打撃5"},
	 {"blow6", "打撃6"},
	 {"blow7", "打撃7"},
	 {"attack1", "攻撃1"},
	 {"attack2", "攻撃2"},
	 {"slash1", "斬る1"},
	 {"slash10", "斬る10"},
	 {"slash11", "斬る11"},
	 {"slash2", "斬る2"},
	 {"slash3", "斬る3"},
	 {"slash4", "斬る4"},
	 {"slash5", "斬る5"},
	 {"slash6", "斬る6"},
	 {"slash7", "斬る7"},
	 {"slash8", "斬る8"},
	 {"slash9", "斬る9"},
	 {"clock", "時計"},
	 {"blind", "暗闇"},
	 {"darkness1", "暗黒1"},
	 {"darkness2", "暗黒2"},
	 {"darkness3", "暗黒3"},
	 {"darkness4", "暗黒4"},
	 {"darkness5", "暗黒5"},
	 {"darkness6", "暗黒6"},
	 {"song", "歌"},
	 {"poison", "毒"},
	 {"water1", "水1"},
	 {"water2", "水2"},
	 {"water3", "水3"},
	 {"water4", "水4"},
	 {"water5", "水5"},
	 {"water6", "水6"},
	 {"decision1", "決定1"},
	 {"decision2", "決定2"},
	 {"silence", "沈黙"},
	 {"sea1", "海1"},
	 {"sea2", "海2"},
	 {"collapse1", "消滅1"},
	 {"collapse2", "消滅2"},
	 {"confusion", "混乱"},
	 {"fire1", "炎1"},
	 {"fire2", "炎2"},
	 {"fire3", "炎3"},
	 {"fire4", "炎4"},
	 {"fire5", "炎5"},
	 {"fire6", "炎6"},
	 {"fire7", "炎7"},
	 {"fire8", "炎8"},
	 {"explosion1", "爆発1"},
	 {"explosion2", "爆発2"},
	 {"explosion3", "爆発3"},
	 {"explosion4", "爆発4"},
	 {"explosion5", "爆発5"},
	 {"explosion6", "爆発6"},
	 {"explosion7", "爆発7"},
	 {"sleep", "睡眠"},
	 {"sandstorm", "砂けむり"},
	 {"holy1", "神聖1"},
	 {"holy2", "神聖2"},
	 {"holy3", "神聖3"},
	 {"holy4", "神聖4"},
	 {"holy5", "神聖5"},
	 {"holy6", "神聖6"},
	 {"holy7", "神聖7"},
	 {"holy8", "神聖8"},
	 {"holy9", "神聖9"},
	 {"move", "移動"},
	 {"pollen", "花粉"},
	 {"fall1", "落ちる1"},
	 {"fall2", "落ちる2"},
	 {"raise1", "蘇生1"},
	 {"raise2", "蘇生2"},
	 {"raise3", "蘇生3"},
	 {"escape", "逃走"},
	 {"key", "鍵"},
	 {"bell", "鐘"},
	 {"close1", "閉める1"},
	 {"close2", "閉める2"},
	 {"open1", "開ける1"},
	 {"open2", "開ける2"},
	 {"rain1", "雨1"},
	 {"rain2", "雨2"},
	 {"thunder1", "雷1"},
	 {"thunder2", "雷2"},
	 {"thunder3", "雷3"},
	 {"thunder4", "雷4"},
	 {"thunder5", "雷5"},
	 {"thunder6", "雷6"},
	 {"thunder7", "雷7"},
	 {"thunder8", "雷8"},
	 {"thunder9", "雷9"},
	 {"thunder10", "雷10"},
	 {"fog1", "霧1"},
	 {"fog2", "霧2"},
	 {"wave1", "音波1"},
	 {"wave2", "音波2"},
	 {"wind1", "風1"},
	 {"wind2", "風2"},
	 {"wind3", "風3"},
	 {"wind4", "風4"},
	 {"wind5", "風5"},
	 {"wind6", "風6"},
	 {"wind7", "風7"},
	 {"wind8", "風8"},
	 {"wind9", "風9"},
	 {"wind10", "風10"},
	 {"wind11", "風11"},
	 {"magic1", "魔法1"},
	 {"magic2", "魔法2"},

	 // RPG Advocate English translation names
	 {"jingle1", "あたり1"},
	 {"jingle2", "あたり2"},
	 {"increase", "アップ"},
	 {"shatter", "ガシャン"},
	 {"decrease", "ダウン"},
	 {"gaze", "にらみ"},
	 {"cat", "ネコ"},
	 {"failure1", "はずれ1"},
	 {"failure2", "はずれ2"},
	 {"buzzer1", "ブザー1"},
	 {"buzzer2", "ブザー2"},
	 {"ice01", "冷気1"},
	 {"ice04", "冷気2"},
	 {"ice05", "冷気3"},
	 {"ice06", "冷気4"},
	 {"ice07", "冷気5"},
	 {"ice08", "冷気6"},
	 {"ice09", "冷気7"},
	 {"ice10", "冷気8"},
	 {"ice11", "冷気9"},
	 {"ice02", "冷気10"},
	 {"ice03", "冷気11"},
	 {"bloodsuck", "噛む"},
	 {"heal1", "回復1"},
	 {"heal2", "回復2"},
	 {"heal3", "回復3"},
	 {"heal4", "回復4"},
	 {"heal5", "回復5"},
	 {"heal6", "回復6"},
	 {"heal7", "回復7"},
	 {"heal8", "回復8"},
	 {"quake1", "地震1"},
	 {"quake2", "地震2"},
	 {"bump1", "壁1"},
	 {"bump2", "壁2"},
	 {"earth01", "大地1"},
	 {"earth02", "大地2"},
	 {"earth03", "大地3"},
	 {"earth04", "大地4"},
	 {"earth05", "大地5"},
	 {"earth06", "大地6"},
	 {"earth07", "大地7"},
	 {"earth08", "大地8"},
	 {"earth09", "大地9"},
	 {"battle1", "戦闘1"},
	 {"battle2", "戦闘2"},
	 {"punch1", "打撃1"},
	 {"punch2", "打撃2"},
	 {"punch3", "打撃3"},
	 {"punch4", "打撃4"},
	 {"punch5", "打撃5"},
	 {"punch6", "打撃6"},
	 {"punch7", "打撃7"},
	 {"strike01", "斬る1"},
	 {"strike10", "斬る10"},
	 {"strike11", "斬る11"},
	 {"strike02", "斬る2"},
	 {"strike03", "斬る3"},
	 {"strike04", "斬る4"},
	 {"strike05", "斬る5"},
	 {"strike06", "斬る6"},
	 {"strike07", "斬る7"},
	 {"strike08", "斬る8"},
	 {"strike09", "斬る9"},
	 {"night", "暗闇"},
	 {"dark1", "暗黒1"},
	 {"dark2", "暗黒2"},
	 {"dark3", "暗黒3"},
	 {"dark4", "暗黒4"},
	 {"dark5", "暗黒5"},
	 {"dark6", "暗黒6"},
	 {"choice1", "決定1"},
	 {"choice2", "決定2"},
	 {"vanish1", "消滅1"},
	 {"vanish2", "消滅2"},
	 {"confuse", "混乱"},
	 {"explode1", "爆発1"},
	 {"explode2", "爆発2"},
	 {"explode3", "爆発3"},
	 {"explode4", "爆発4"},
	 {"explode5", "爆発5"},
	 {"explode6", "爆発6"},
	 {"explode7", "爆発7"},
	 {"footstep", "移動"},
	 {"revive1", "蘇生1"},
	 {"revive2", "蘇生2"},
	 {"revive3", "蘇生3"},
	 {"flee", "逃走"},
	 {"gong", "鐘"},
	 {"bolt01", "雷1"},
	 {"bolt02", "雷2"},
	 {"bolt03", "雷3"},
	 {"bolt04", "雷4"},
	 {"bolt05", "雷5"},
	 {"bolt06", "雷6"},
	 {"bolt07", "雷7"},
	 {"bolt08", "雷8"},
	 {"bolt09", "雷9"},
	 {"bolt10", "雷10"},
	 {"wind01", "風1"},
	 {"wind02", "風2"},
	 {"wind03", "風3"},
	 {"wind04", "風4"},
	 {"wind05", "風5"},
	 {"wind06", "風6"},
	 {"wind07", "風7"},
	 {"wind08", "風8"},
	 {"wind09", "風9"},

	 // Unknown English translation names used by Spanish games
	 {"around1", "あたり1"},
	 {"around2", "あたり2"},
	 {"upgrade", "アップ"},
	 {"glass", "ガシャン"},
	 {"laser1", "ショット1"},
	 {"laser2", "ショット2"},
	 {"laser3", "ショット3"},
	 {"downgrade", "ダウン"},
	 {"damege1", "ダメージ1"},
	 {"damege2", "ダメージ2"},
	 {"glare", "にらみ"},
	 {"end1", "はずれ1"},
	 {"end2", "はずれ2"},
	 {"flashlight1", "フラッシュ1"},
	 {"flashlight2", "フラッシュ2"},
	 {"flashlight3", "フラッシュ3"},
	 {"ice1", "冷気1"},
	 {"ice2", "冷気2"},
	 {"ice3", "冷気3"},
	 {"ice4", "冷気4"},
	 {"ice5", "冷気5"},
	 {"ice6", "冷気6"},
	 {"ice7", "冷気7"},
	 {"ice8", "冷気8"},
	 {"ice9", "冷気9"},
	 {"ice10", "冷気10"},
	 {"ice11", "冷気11"},
	 {"absorption1", "吸収1"},
	 {"absorption2", "吸収2"},
	 {"bite", "噛む"},
	 {"recovery1", "回復1"},
	 {"recovery2", "回復2"},
	 {"recovery3", "回復3"},
	 {"recovery4", "回復4"},
	 {"recovery5", "回復5"},
	 {"recovery6", "回復6"},
	 {"recovery7", "回復7"},
	 {"recovery8", "回復8"},
	 {"evasion1", "回避1"},
	 {"evasion2", "回避2"},
	 {"earthquake1", "地震1"},
	 {"earthquake2", "地震2"},
	 {"wall1", "壁1"},
	 {"wall2", "壁2"},
	 {"earth1", "大地1"},
	 {"earth2", "大地2"},
	 {"earth3", "大地3"},
	 {"earth4", "大地4"},
	 {"earth5", "大地5"},
	 {"earth6", "大地6"},
	 {"earth7", "大地7"},
	 {"earth8", "大地8"},
	 {"earth9", "大地9"},
	 {"vortex", "巻き付き"},
	 {"blow1", "打撃1"},
	 {"blow2", "打撃2"},
	 {"blow3", "打撃3"},
	 {"blow4", "打撃4"},
	 {"blow5", "打撃5"},
	 {"blow6", "打撃6"},
	 {"blow7", "打撃7"},
	 {"cut1", "斬る1"},
	 {"cut10", "斬る10"},
	 {"cut11", "斬る11"},
	 {"cut2", "斬る2"},
	 {"cut3", "斬る3"},
	 {"cut4", "斬る4"},
	 {"cut5", "斬る5"},
	 {"cut6", "斬る6"},
	 {"cut7", "斬る7"},
	 {"cut8", "斬る8"},
	 {"cut9", "斬る9"},
	 {"darkness", "暗闇"},
	 {"darkness1", "暗黒1"},
	 {"darkness2", "暗黒2"},
	 {"darkness3", "暗黒3"},
	 {"darkness4", "暗黒4"},
	 {"darkness5", "暗黒5"},
	 {"darkness6", "暗黒6"},
	 {"decision1", "決定1"},
	 {"decision2", "決定2"},
	 {"disappearance1", "消滅1"},
	 {"disappearance2", "消滅2"},
	 {"caos", "混乱"},
	 {"flame1", "炎1"},
	 {"flame2", "炎2"},
	 {"flame3", "炎3"},
	 {"flame4", "炎4"},
	 {"flame5", "炎5"},
	 {"flame6", "炎6"},
	 {"flame7", "炎7"},
	 {"flame8", "炎8"},
	 {"explosion1", "爆発1"},
	 {"explosion2", "爆発2"},
	 {"explosion3", "爆発3"},
	 {"explosion4", "爆発4"},
	 {"explosion5", "爆発5"},
	 {"explosion6", "爆発6"},
	 {"explosion7", "爆発7"},
	 {"sandmind", "砂けむり"},
	 {"run", "移動"},
	 {"revival1", "蘇生1"},
	 {"revival2", "蘇生2"},
	 {"revival3", "蘇生3"},
	 {"escape", "逃走"},
	 {"bell", "鐘"},
	 {"thunder1", "雷1"},
	 {"thunder2", "雷2"},
	 {"thunder3", "雷3"},
	 {"thunder4", "雷4"},
	 {"thunder5", "雷5"},
	 {"thunder6", "雷6"},
	 {"thunder7", "雷7"},
	 {"thunder8", "雷8"},
	 {"thunder9", "雷9"},
	 {"thunder10", "雷10"},
	 {"sound wave1", "音波1"},
	 {"sound wave2", "音波2"},
	 {"wind1", "風1"},
	 {"wind2", "風2"},
	 {"wind3", "風3"},
	 {"wind4", "風4"},
	 {"wind5", "風5"},
	 {"wind6", "風6"},
	 {"wind7", "風7"},
	 {"wind8", "風8"},
	 {"wind9", "風9"},

	 // 2000 RTP names not overwritten by Vlad Kovnerov's installation
	 {"success1", "あたり1"},
	 {"success2", "あたり2"},
	 {"up", "アップ"},
	 {"glass", "ガシャン"},
	 {"cansel1", "キャンセル1"},
	 {"cansel2", "キャンセル2"},
	 {"numbness1", "しびれ1"},
	 {"numbness2", "しびれ2"},
	 {"numbness3", "しびれ3"},
	 {"down", "ダウン"},
	 {"power", "にらみ"},
	 {"breast", "ブレス"},
	 {"cold1", "冷気1"},
	 {"cold2", "冷気2"},
	 {"cold3", "冷気3"},
	 {"cold4", "冷気4"},
	 {"cold5", "冷気5"},
	 {"cold6", "冷気6"},
	 {"cold7", "冷気7"},
	 {"cold8", "冷気8"},
	 {"cold9", "冷気9"},
	 {"cold10", "冷気10"},
	 {"cold11", "冷気11"},
	 {"refer book", "巻き付き"},
	 {"fight1", "戦闘1"},
	 {"fight2", "戦闘2"},
	 {"kill1", "斬る1"},
	 {"kill2", "斬る2"},
	 {"kill3", "斬る3"},
	 {"kill4", "斬る4"},
	 {"kill5", "斬る5"},
	 {"kill6", "暗黒6"},
	 {"kill7", "斬る7"},
	 {"kill8", "斬る8"},
	 {"kill9", "斬る9"},
	 {"kill10", "斬る10"},
	 {"kill11", "斬る11"},
	 {"annihilation1", "消滅1"},
	 {"annihilation2", "消滅2"},
	 {"chaos", "混乱"},
	 {"sand storm", "砂けむり"},
	 {"movement", "移動"},
	 {"rebirth1", "蘇生1"},
	 {"rebirth2", "蘇生2"},
	 {"rebirth3", "蘇生3"},
	 {"sonic1", "音波1"},
	 {"sonic2", "音波2"},

	 // Korean RTP
	 {"냉기10", "冷気10"},
	 {"대지10", "大地10"},
	 {"벤다10", "斬る10"},
	 {"전격10", "雷10"},
	 {"바람10", "風10"},
	 {"냉기11", "冷気11"},
	 {"벤다11", "斬る11"},
	 {"바람11", "風11"},
	 {"텔레포트1", "テレポート1"},
	 {"즈음하고1", "あたり1"},
	 {"잘라내기1", "はずれ1"},
	 {"플래시1", "フラッシュ1"},
	 {"몬스터1", "モンスター1"},
	 {"데미지1", "ダメージ1"},
	 {"스위치1", "スイッチ1"},
	 {"아이템1", "アイテム1"},
	 {"취소1", "キャンセル1"},
	 {"커서1", "カーソル1"},
	 {"점프1", "ジャンプ1"},
	 {"쇼트1", "ショット1"},
	 {"버저1", "ブザー1"},
	 {"마비1", "しびれ1"},
	 {"냉기1", "冷気1"},
	 {"검1", "剣1"},
	 {"흡수1", "吸収1"},
	 {"회복1", "回復1"},
	 {"회피1", "回避1"},
	 {"지진1", "地震1"},
	 {"벽1", "壁1"},
	 {"대지1", "大地1"},
	 {"활1", "弓1"},
	 {"전투1", "戦闘1"},
	 {"타격1", "打撃1"},
	 {"공격1", "攻撃1"},
	 {"벤다1", "斬る1"},
	 {"암흑1", "暗黒1"},
	 {"물1", "水1"},
	 {"결정1", "決定1"},
	 {"바다1", "海1"},
	 {"소멸1", "消滅1"},
	 {"화염1", "炎1"},
	 {"폭발1", "爆発1"},
	 {"신성1", "神聖1"},
	 {"떨어진다1", "落ちる1"},
	 {"소생1", "蘇生1"},
	 {"닫는다1", "閉める1"},
	 {"열다1", "開ける1"},
	 {"비1", "雨1"},
	 {"전격1", "雷1"},
	 {"안개1", "霧1"},
	 {"음파1", "音波1"},
	 {"바람1", "風1"},
	 {"마법1", "魔法1"},
	 {"텔레포트2", "テレポート2"},
	 {"잘라내기2", "はずれ2"},
	 {"즈음하고2", "あたり2"},
	 {"플래시2", "フラッシュ2"},
	 {"몬스터2", "モンスター2"},
	 {"데미지2", "ダメージ2"},
	 {"아이템2", "アイテム2"},
	 {"스위치2", "スイッチ2"},
	 {"취소2", "キャンセル2"},
	 {"쇼트2", "ショット2"},
	 {"점프2", "ジャンプ2"},
	 {"커서2", "カーソル2"},
	 {"마비2", "しびれ2"},
	 {"버저2", "ブザー2"},
	 {"냉기2", "冷気2"},
	 {"검2", "剣2"},
	 {"흡수2", "吸収2"},
	 {"회복2", "回復2"},
	 {"회피2", "回避2"},
	 {"지진2", "地震2"},
	 {"벽2", "壁2"},
	 {"대지2", "大地2"},
	 {"활2", "弓2"},
	 {"전투2", "戦闘2"},
	 {"타격2", "打撃2"},
	 {"공격2", "攻撃2"},
	 {"벤다2", "斬る2"},
	 {"암흑2", "暗黒2"},
	 {"물2", "水2"},
	 {"결정2", "決定2"},
	 {"바다2", "海2"},
	 {"소멸2", "消滅2"},
	 {"화염2", "炎2"},
	 {"폭발2", "爆発2"},
	 {"신성2", "神聖2"},
	 {"떨어진다2", "落ちる2"},
	 {"소생2", "蘇生2"},
	 {"닫는다2", "閉める2"},
	 {"열다2", "開ける2"},
	 {"비2", "雨2"},
	 {"전격2", "雷2"},
	 {"안개2", "霧2"},
	 {"음파2", "音波2"},
	 {"바람2", "風2"},
	 {"마법2", "魔法2"},
	 {"플래시3", "フラッシュ3"},
	 {"쇼트3", "ショット3"},
	 {"마비3", "しびれ3"},
	 {"냉기3", "冷気3"},
	 {"검3", "剣3"},
	 {"회복3", "回復3"},
	 {"대지3", "大地3"},
	 {"타격3", "打撃3"},
	 {"벤다3", "斬る3"},
	 {"암흑3", "暗黒3"},
	 {"물3", "水3"},
	 {"화염3", "炎3"},
	 {"폭발3", "爆発3"},
	 {"신성3", "神聖3"},
	 {"소생3", "蘇生3"},
	 {"전격3", "雷3"},
	 {"바람3", "風3"},
	 {"냉기4", "冷気4"},
	 {"회복4", "回復4"},
	 {"대지4", "大地4"},
	 {"타격4", "打撃4"},
	 {"벤다4", "斬る4"},
	 {"암흑4", "暗黒4"},
	 {"물4", "水4"},
	 {"화염4", "炎4"},
	 {"폭발4", "爆発4"},
	 {"신성4", "神聖4"},
	 {"전격4", "雷4"},
	 {"바람4", "風4"},
	 {"냉기5", "冷気5"},
	 {"회복5", "回復5"},
	 {"대지5", "大地5"},
	 {"타격5", "打撃5"},
	 {"벤다5", "斬る5"},
	 {"암흑5", "暗黒5"},
	 {"물5", "水5"},
	 {"화염5", "炎5"},
	 {"폭발5", "爆発5"},
	 {"신성5", "神聖5"},
	 {"전격5", "雷5"},
	 {"바람5", "風5"},
	 {"냉기6", "冷気6"},
	 {"회복6", "回復6"},
	 {"대지6", "大地6"},
	 {"타격6", "打撃6"},
	 {"벤다6", "斬る6"},
	 {"암흑6", "暗黒6"},
	 {"물6", "水6"},
	 {"화염6", "炎6"},
	 {"폭발6", "爆発6"},
	 {"신성6", "神聖6"},
	 {"전격6", "雷6"},
	 {"바람6", "風6"},
	 {"냉기7", "冷気7"},
	 {"회복7", "回復7"},
	 {"대지7", "大地7"},
	 {"타격7", "打撃7"},
	 {"벤다7", "斬る7"},
	 {"화염7", "炎7"},
	 {"폭발7", "爆発7"},
	 {"신성7", "神聖7"},
	 {"전격7", "雷7"},
	 {"바람7", "風7"},
	 {"냉기8", "冷気8"},
	 {"회복8", "回復8"},
	 {"대지8", "大地8"},
	 {"벤다8", "斬る8"},
	 {"화염8", "炎8"},
	 {"신성8", "神聖8"},
	 {"전격8", "雷8"},
	 {"바람8", "風8"},
	 {"냉기9", "冷気9"},
	 {"대지9", "大地9"},
	 {"벤다9", "斬る9"},
	 {"신성9", "神聖9"},
	 {"전격9", "雷9"},
	 {"바람9", "風9"},
	 {"소", "ウシ"},
	 {"양", "ひつじ"},
	 {"업", "アップ"},
	 {"닭", "にわとり"},
	 {"발판", "ウマ"},
	 {"트럭", "トラ"},
	 {"노크", "ノック"},
	 {"다운", "ダウン"},
	 {"호흡", "ブレス"},
	 {"사자", "ライオン"},
	 {"가샨", "ガシャン"},
	 {"우렁찬 외침", "おたけび"},
	 {"고양이", "ネコ"},
	 {"강아지", "イヌ"},
	 {"배리어", "バリア"},
	 {"노려봄", "にらみ"},
	 {"물다", "噛む"},
	 {"달라붙기", "巻き付き"},
	 {"시계", "時計"},
	 {"안보임", "暗闇"},
	 {"노래", "歌"},
	 {"독", "毒"},
	 {"침묵", "沈黙"},
	 {"혼란", "混乱"},
	 {"수면", "睡眠"},
	 {"모래 연기", "砂けむり"},
	 {"이동", "移動"},
	 {"꽃가루", "花粉"},
	 {"도주", "逃走"},
	 {"자물쇠", "鍵"},
	 {"종", "鐘"}
	};

	RTP_TABLE_2003["system"] = {
	 // Official English translation names
	 {"system", "システム"},
	 {"systema", "システムa"},
	 {"systemb", "システムb"},
	 {"systemc", "システムc"},

	 // RPG Advocate English translation names
	 {"system1", "システム"},
	 {"system2", "システムa"},
	 {"system3", "システムb"},
	 {"system4", "システムc"},

	 // Orphaned Don Miguel's 2000 RTP extras pointing to nearest match
	 {"royal", "システム"},

	 // Korean RTP
	 {"시스템", "システム"},
	 {"시스템a", "システムa"},
	 {"시스템b", "システムb"},
	 {"시스템c", "システムc"}
	};

	RTP_TABLE_2003["system2"] = {
	 // Official English translation names
	 {"system2a", "システム２a"},
	 {"system2b", "システム２b"},
	 {"system2c", "システム２c"},

	 // Unknown English translation names used by Spanish games
	 {"systeméqa", "システム２a"},
	 {"systeméqb", "システム２b"},
	 {"systeméqc", "システム２c"},

	 // Korean RTP
	 {"시스템２a", "システム２a"},
	 {"시스템２b", "システム２b"},
	 {"시스템２c", "システム２c"}
	};

	RTP_TABLE_2003["title"] = {
	 // Official English translation names
	 {"title1", "タイトル1"},
	 {"title2", "タイトル2"},
	 {"title3", "タイトル3"},
	 {"title4", "タイトル4"},

	 // Korean RTP
	 {"타이틀1", "タイトル1"},
	 {"타이틀2", "タイトル2"},
	 {"타이틀3", "タイトル3"},
	 {"타이틀4", "タイトル4"}
	};

	RTP_TABLE_2000["backdrop"] = {
	 // Official English translation names
	 {"dungeon1", "ダンジョン1"},
	 {"dungeon2", "ダンジョン2"},
	 {"dungeon3", "ダンジョン3"},
	 {"dungeon4", "ダンジョン4"},
	 {"dungeon5", "ダンジョン5"},
	 {"space", "宇宙"},
	 {"mountainpath", "山道"},
	 {"rockyarea", "岩場"},
	 {"ruins", "廃墟"},
	 {"forest1", "森1"},
	 {"forest2", "森2"},
	 {"bridge", "橋"},
	 {"poisonswamp", "毒沼"},
	 {"sea", "海"},
	 {"throne", "玉座"},
	 {"strangespace", "異空間"},
	 {"sandybeach", "砂浜"},
	 {"desert", "砂漠"},
	 {"shrine", "神殿"},
	 {"sky", "空"},
	 {"shipdeck", "船上"},
	 {"grassland", "草原"},
	 {"wasteland", "荒地"},
	 {"downtown", "街中"},
	 {"snowfield", "雪原"},

	 // Don Miguel's English translation names
	 {"cave1", "ダンジョン1"},
	 {"lavacave2", "ダンジョン2"},
	 {"icecave3", "ダンジョン3"},
	 {"cave4", "ダンジョン4"},
	 {"brickcave5", "ダンジョン5"},
	 {"galaxy", "宇宙"},
	 {"canyon", "山道"},
	 {"snowcanyon", "岩場"},
	 {"wasteruins", "廃墟"},
	 {"swamp", "毒沼"},
	 {"castle", "玉座"},
	 {"lightspeed", "異空間"},
	 {"seabeach", "砂浜"},
	 {"greece", "神殿"},
	 {"ship", "船上"},
	 {"grass", "草原"},
	 {"town", "街中"},
	 {"snow", "雪原"}
	};

	RTP_TABLE_2000["battle"] = {
	 // Official English translation names
	 {"other", "その他"},
	 {"barrier", "バリア"},
	 {"breath", "ブレス"},
	 {"buff", "上昇"},
	 {"debuff", "下降"},
	 {"ice", "冷気"},
	 {"sword1", "剣1"},
	 {"sword2", "剣2"},
	 {"bite", "吸収"},
	 {"recovery", "回復"},
	 {"earth", "大地"},
	 {"blow", "打撃"},
	 {"axe", "斧"},
	 {"dark", "暗黒"},
	 {"spear", "槍"},
	 {"water", "水"},
	 {"treatment", "治療"},
	 {"fire1", "炎1"},
	 {"fire2", "炎2"},
	 {"explosion", "爆発"},
	 {"claw", "爪"},
	 {"arrow", "矢"},
	 {"holy", "神聖"},
	 {"ressurection", "蘇生"},
	 {"thunder", "雷"},
	 {"whip", "鞭"},
	 {"wind", "風"},
	 {"paralysis", "麻痺"},

	 // Don Miguel's English translation names
	 {"etc", "その他"},
	 {"poison", "ブレス"},
	 {"up", "上昇"},
	 {"down", "下降"},
	 {"cold", "冷気"},
	 {"absorption", "吸収"},
	 {"sun", "回復"},
	 {"hit", "打撃"},
	 {"sphere", "治療"},
	 {"fang", "爪"},
	 {"ray", "蘇生"},
	 {"zip", "雷"}
	};

	RTP_TABLE_2000["charset"] = {
	 // Official English translation names
	 {"object1", "オブジェクト1"},
	 {"object2", "オブジェクト2"},
	 {"monster1", "モンスター1"},
	 {"monster2", "モンスター2"},
	 {"people1", "一般1"},
	 {"people2", "一般2"},
	 {"people3", "一般3"},
	 {"people4", "一般4"},
	 {"people5", "一般5"},
	 {"actor1", "主人公1"},
	 {"actor2", "主人公2"},
	 {"actor3", "主人公3"},
	 {"actor4", "主人公4"},
	 {"vehicles", "乗り物"},
	 {"animal", "動物"},

	 // Don Miguel's English translation names
	 {"people7", "一般2"},
	 {"chara1", "主人公1"},
	 {"chara2", "主人公2"},
	 {"chara3", "主人公3"},
	 {"chara4", "主人公4"},
	 {"vehicle", "乗り物"},

	 // Orphaned Don Miguel's 2000 RTP extras pointing to nearest match
	 {"chubby1", "一般3"},
	 {"chubby2", "一般2"},
	 {"crown1", "主人公4"},
	 {"crown2", "モンスター2"},
	 {"crown3", "モンスター1"},
	 {"crown4", "動物"},
	 {"crown5", "一般5"},
	 {"crown6", "モンスター1"},
	 {"crown7", "動物"},
	 {"future1", "一般1"},
	 {"future2", "一般4"},
	 {"future3", "一般5"},
	 {"men1", "一般4"},
	 {"women1", "一般5"}
	};

	RTP_TABLE_2000["chipset"] = {
	 // Official English translation names
	 {"dungeon", "ダンジョン"},
	 {"interior", "内装"},
	 {"world", "基本"},
	 {"exterior", "外観"},
	 {"ship", "船"},

	 // Don Miguel's English translation names
	 {"inner", "内装"},
	 {"basis", "基本"},
	 {"outline", "外観"},

	 // Orphaned Don Miguel's 2000 RTP extras pointing to nearest match
	 {"chipset1", "ダンジョン"},
	 {"chipset2", "内装"},
	 {"chipset3", "船"}
	};

	RTP_TABLE_2000["faceset"] = {
	 // Official English translation names
	 {"monster", "モンスター"},
	 {"people1", "一般1"},
	 {"people2", "一般2"},
	 {"actor1", "主人公1"},
	 {"actor2", "主人公2"},

	 // Don Miguel's English translation names
	 {"monsters", "モンスター"},
	 {"chara1", "主人公1"},
	 {"chara2", "主人公2"}

	 // Orphaned Don Miguel's 2000 RTP extras with no match
	 // face1-4
	};

	RTP_TABLE_2000["gameover"] = {
	 // Official English translation names
	 {"game over", "ゲームオーバー"},

	 // Don Miguel's English translation names
	 {"gameover", "ゲームオーバー"}
	};

	RTP_TABLE_2000["monster"] = {
	 // Official English translation names
	 {"vampire", "ヴァンパイア"},
	 {"orc", "オーク"},
	 {"gargoyle", "ガーゴイル"},
	 {"chimera", "キマイラ"},
	 {"kraken", "クラーケン"},
	 {"griffon", "グリフォン"},
	 {"cerberus", "ケルベロス"},
	 {"bat", "こうもり"},
	 {"ghost", "ゴースト"},
	 {"golem", "ゴーレム"},
	 {"cockatorice", "コカトリス"},
	 {"goblin", "ゴブリン"},
	 {"kobold", "コボルト"},
	 {"skeleton", "スケルトン"},
	 {"slime", "スライム"},
	 {"zombie", "ゾンビ"},
	 {"dark elf", "ダークエルフ"},
	 {"demon", "デーモン"},
	 {"dragona", "ドラゴン"},
	 {"dragon knight", "ドラゴンナイト"},
	 {"knight", "トルーパー"},
	 {"treant", "トレント"},
	 {"harpy", "ハーピー"},
	 {"hydra", "ヒュドラ"},
	 {"black knight", "ブラックナイト"},
	 {"hornet", "ホーネット"},
	 {"merman", "マーマン"},
	 {"mummy", "マミー"},
	 {"minotaur", "ミノタウロス"},
	 {"mimic", "ミミック"},
	 {"medusa", "メデューサ"},
	 {"lizardman", "リザードマン"},
	 {"lich", "リッチ"},
	 {"werewolf", "ワーウルフ"},
	 {"wyvern", "ワイバーン"},
	 {"people1", "一般人1"},
	 {"people2", "一般人2"},
	 {"people3", "一般人3"},
	 {"people4", "一般人4"},
	 {"people5", "一般人5"},
	 {"people6", "一般人6"},
	 {"people7", "一般人7"},
	 {"people8", "一般人8"},
	 {"familiar", "使い魔"},
	 {"soldier", "兵士"},
	 {"giant spider", "大グモ"},
	 {"giant scorpion", "大サソリ"},
	 {"snake", "大蛇"},
	 {"angel", "天使"},
	 {"queen", "女王"},
	 {"ninja", "忍者"},
	 {"monster fish", "怪魚"},
	 {"warrior1", "戦士1"},
	 {"warrior2", "戦士2"},
	 {"warrior", "武者"},
	 {"reaper", "死神"},
	 {"pirate", "海賊"},
	 {"king", "王"},
	 {"thief", "盗賊"},
	 {"wisp", "鬼火"},
	 {"demon lord", "魔王"},
	 {"demon god", "魔神"},
	 {"magician1", "魔術師1"},
	 {"magician2", "魔術師2"},
	 {"dragonb", "龍"},

	 // Don Miguel's English translation names
	 {"hog", "オーク"},
	 {"octopus", "クラーケン"},
	 {"griphon", "グリフォン"},
	 {"hellhound", "ケルベロス"},
	 {"rooster", "コカトリス"},
	 {"troll", "ゴブリン"},
	 {"wolfman", "コボルト"},
	 {"darkelf", "ダークエルフ"},
	 {"flyingdemon", "デーモン"},
	 {"greendragon1", "ドラゴン"},
	 {"dragonknight", "ドラゴンナイト"},
	 {"darkrider", "トルーパー"},
	 {"oak", "トレント"},
	 {"darkknight", "ブラックナイト"},
	 {"bee", "ホーネット"},
	 {"aquamen", "マーマン"},
	 {"ogrechest", "ミミック"},
	 {"lizardmen", "リザードマン"},
	 {"darkspirit", "リッチ"},
	 {"wolf", "ワーウルフ"},
	 {"bluedragon", "ワイバーン"},
	 {"boy1", "一般人1"},
	 {"girl2", "一般人2"},
	 {"boy3", "一般人3"},
	 {"girl4", "一般人4"},
	 {"man5", "一般人5"},
	 {"girl6", "一般人6"},
	 {"oldman7", "一般人7"},
	 {"granny", "一般人8"},
	 {"imp", "使い魔"},
	 {"warrior", "兵士"},
	 {"spider", "大グモ"},
	 {"redscorpion", "大サソリ"},
	 {"princess", "女王"},
	 {"fish", "怪魚"},
	 {"hero1", "戦士1"},
	 {"hero2", "戦士2"},
	 {"samurai", "武者"},
	 {"death", "死神"},
	 {"gnome", "海賊"},
	 {"firescull", "鬼火"},
	 {"cloakdemon", "魔王"},
	 {"satan", "魔神"},
	 {"witch1", "魔術師1"},
	 {"witch2", "魔術師2"},
	 {"greendragon2", "龍"}
	};

	RTP_TABLE_2000["music"] = {
	 // Official English translation names
	 {"items", "jアイテム"},
	 {"gag1", "jギャグ1"},
	 {"gag2", "jギャグ2"},
	 {"fanfare1", "jファンファーレ1"},
	 {"fanfare2", "jファンファーレ2"},
	 {"fanfare3", "jファンファーレ3"},
	 {"fanfare4", "jファンファーレ4"},
	 {"fanfare5", "jファンファーレ5"},
	 {"fanfare6", "jファンファーレ6"},
	 {"inn1", "j宿1"},
	 {"inn2", "j宿2"},
	 {"battleend1", "j戦闘終了1"},
	 {"battleend2", "j戦闘終了2"},
	 {"battleend3", "j戦闘終了3"},
	 {"battleend4", "j戦闘終了4"},
	 {"suspicion", "j疑惑"},
	 {"mystery", "j謎"},
	 {"earthquake", "se地震"},
	 {"rain2", "se大雨"},
	 {"clock", "se時計"},
	 {"sea", "se海"},
	 {"rain1", "se雨"},
	 {"ending1", "エンディング1"},
	 {"ending2", "エンディング2"},
	 {"ending3", "エンディング3"},
	 {"opening1", "オープニング1"},
	 {"opening2", "オープニング2"},
	 {"opening3", "オープニング3"},
	 {"gameover1", "ゲームオーバー1"},
	 {"gameover2", "ゲームオーバー2"},
	 {"gameover3", "ゲームオーバー3"},
	 {"ghosttown1", "ゴーストタウン1"},
	 {"ghosttown2", "ゴーストタウン2"},
	 {"dungeon1", "ダンジョン1"},
	 {"dungeon2", "ダンジョン2"},
	 {"dungeon3", "ダンジョン3"},
	 {"dungeon4", "ダンジョン4"},
	 {"dungeon5", "ダンジョン5"},
	 {"crisis", "ピンチ"},
	 {"field1", "フィールド1"},
	 {"field2", "フィールド2"},
	 {"field3", "フィールド3"},
	 {"field4", "フィールド4"},
	 {"boss1", "ボス1"},
	 {"boss2", "ボス2"},
	 {"boss3", "ボス3"},
	 {"boss4", "ボス4"},
	 {"vehicle1", "乗り物1"},
	 {"vehicle2", "乗り物2"},
	 {"vehicle3", "乗り物3"},
	 {"farewell1", "別れ1"},
	 {"farewell2", "別れ2"},
	 {"hero1", "勇者1"},
	 {"hero2", "勇者2"},
	 {"animal", "動物"},
	 {"victory", "勝利"},
	 {"castle1", "城1"},
	 {"castle2", "城2"},
	 {"castle3", "城3"},
	 {"tower1", "塔1"},
	 {"tower2", "塔2"},
	 {"tower3", "塔3"},
	 {"fairy1", "妖精1"},
	 {"fairy2", "妖精2"},
	 {"peace1", "安らぎ1"},
	 {"peace2", "安らぎ2"},
	 {"peace3", "安らぎ3"},
	 {"store1", "店1"},
	 {"store2", "店2"},
	 {"store3", "店3"},
	 {"anger", "怒り"},
	 {"sorrow", "悲しみ"},
	 {"battle1", "戦闘1"},
	 {"battle2", "戦闘2"},
	 {"battle3", "戦闘3"},
	 {"search", "探索"},
	 {"defeat", "敗北"},
	 {"church", "教会"},
	 {"marketplace", "明るい市場"},
	 {"village1", "村1"},
	 {"village2", "村2"},
	 {"village3", "村3"},
	 {"thief", "泥棒"},
	 {"energy", "活気"},
	 {"town1", "町1"},
	 {"town2", "町2"},
	 {"town3", "町3"},
	 {"mystery1", "神秘1"},
	 {"mystery2", "神秘2"},
	 {"mystery3", "神秘3"},
	 {"treasure", "秘宝"},
	 {"ship1", "船1"},
	 {"ship2", "船2"},
	 {"ship3", "船3"},
	 {"trial", "試練"},
	 {"blackmarket", "闇市"},
	 {"devil", "魔王"},

	 // Don Miguel's English translation names
	 {"item", "jアイテム"},
	 {"doubt", "j疑惑"},
	 {"riddle", "j謎"},
	 {"seearthquake", "se地震"},
	 {"serain2", "se大雨"},
	 {"seclock", "se時計"},
	 {"sesea", "se海"},
	 {"serain", "se雨"},
	 {"gosttown1", "ゴーストタウン1"},
	 {"gosttown2", "ゴーストタウン2"},
	 {"ride1", "乗り物1"},
	 {"ride2", "乗り物2"},
	 {"ride3", "乗り物3"},
	 {"get", "勝利"},
	 {"shop1", "店1"},
	 {"shop2", "店2"},
	 {"shop3", "店3"},
	 {"sad", "悲しみ"},
	 {"lose", "敗北"},
	 {"fiesta", "明るい市場"},
	 {"dark", "闇市"}

	 // Orphaned Don Miguel's 2000 RTP extras with no match
	 // inn3 shop4 night dungeon6/7 snow
	 // ride4 mystery4 farewell3/4 pirate1-4
	};

	RTP_TABLE_2000["panorama"] = {
	 // Official English translation names
	 {"sunset1", "夕焼け1"},
	 {"sunset2", "夕焼け2"},
	 {"dawn1", "夜明け1"},
	 {"dawn2", "夜明け2"},
	 {"night sky1", "夜空1"},
	 {"night sky2", "夜空2"},
	 {"cosmos1", "宇宙"},
	 {"planet1", "惑星1"},
	 {"planet2", "惑星2"},
	 {"planet3", "惑星3"},
	 {"dimension rift", "異空間"},
	 {"sky1", "空1"},
	 {"sky2", "空2"},

	 // Don Miguel's English translation names
	 {"dawn1", "夕焼け1"},
	 {"dawn2", "夕焼け2"},
	 {"evening1", "夜明け1"},
	 {"evening2", "夜明け2"},
	 {"night1", "夜空1"},
	 {"night2", "夜空2"},
	 {"galaxy", "宇宙"},
	 {"weird", "異空間"},
	 {"morning1", "空1"},
	 {"morning2", "空2"}
	};

	RTP_TABLE_2000["sound"] = {
	 // Official English translation names
	 {"item1", "アイテム1"},
	 {"item2", "アイテム2"},
	 {"chime1", "あたり1"},
	 {"chime2", "あたり2"},
	 {"buff", "アップ"},
	 {"dog", "イヌ"},
	 {"cow", "ウシ"},
	 {"horse", "ウマ"},
	 {"roar", "おたけび"},
	 {"cursor1", "カーソル1"},
	 {"cursor2", "カーソル2"},
	 {"glassshatter", "ガシャン"},
	 {"cancel1", "キャンセル1"},
	 {"cancel2", "キャンセル2"},
	 {"paralyze1", "しびれ1"},
	 {"paralyze2", "しびれ2"},
	 {"paralyze3", "しびれ3"},
	 {"jump1", "ジャンプ1"},
	 {"jump2", "ジャンプ2"},
	 {"shot1", "ショット1"},
	 {"shot2", "ショット2"},
	 {"shot3", "ショット3"},
	 {"switch1", "スイッチ1"},
	 {"switch2", "スイッチ2"},
	 {"debuff", "ダウン"},
	 {"damage1", "ダメージ1"},
	 {"damage2", "ダメージ2"},
	 {"teleport1", "テレポート1"},
	 {"teleport2", "テレポート2"},
	 {"tiger", "トラ"},
	 {"glare", "にらみ"},
	 {"chicken", "にわとり"},
	 {"cat", "ネコ"},
	 {"knock", "ノック"},
	 {"buzzer1", "はずれ1"},
	 {"buzzer2", "はずれ2"},
	 {"barrier", "バリア"},
	 {"sheep", "ひつじ"},
	 {"buzzer3", "ブザー1"},
	 {"buzzer4", "ブザー2"},
	 {"flash1", "フラッシュ1"},
	 {"flash2", "フラッシュ2"},
	 {"flash3", "フラッシュ3"},
	 {"breath", "ブレス"},
	 {"monster1", "モンスター1"},
	 {"monster2", "モンスター2"},
	 {"lion", "ライオン"},
	 {"ice1", "冷気1"},
	 {"ice2", "冷気2"},
	 {"ice3", "冷気3"},
	 {"ice4", "冷気4"},
	 {"ice5", "冷気5"},
	 {"ice6", "冷気6"},
	 {"ice7", "冷気7"},
	 {"ice8", "冷気8"},
	 {"ice9", "冷気9"},
	 {"ice10", "冷気10"},
	 {"ice11", "冷気11"},
	 {"sword1", "剣1"},
	 {"sword2", "剣2"},
	 {"sword3", "剣3"},
	 {"absorb1", "吸収1"},
	 {"absorb2", "吸収2"},
	 {"bite", "噛む"},
	 {"recovery1", "回復1"},
	 {"recovery2", "回復2"},
	 {"recovery3", "回復3"},
	 {"recovery4", "回復4"},
	 {"recovery5", "回復5"},
	 {"recovery6", "回復6"},
	 {"recovery7", "回復7"},
	 {"recovery8", "回復8"},
	 {"evade1", "回避1"},
	 {"evade2", "回避2"},
	 {"earthquake1", "地震1"},
	 {"earthquake2", "地震2"},
	 {"barrier1", "壁1"},
	 {"barrier2", "壁2"},
	 {"earth1", "大地1"},
	 {"earth2", "大地2"},
	 {"earth3", "大地3"},
	 {"earth4", "大地4"},
	 {"earth5", "大地5"},
	 {"earth6", "大地6"},
	 {"earth7", "大地7"},
	 {"earth8", "大地8"},
	 {"earth9", "大地9"},
	 {"earth10", "大地10"},
	 {"ensnare", "巻き付き"},
	 {"bow1", "弓1"},
	 {"bow2", "弓2"},
	 {"combat1", "戦闘1"},
	 {"combat2", "戦闘2"},
	 {"blow1", "打撃1"},
	 {"blow2", "打撃2"},
	 {"blow3", "打撃3"},
	 {"blow4", "打撃4"},
	 {"blow5", "打撃5"},
	 {"blow6", "打撃6"},
	 {"blow7", "打撃7"},
	 {"attack1", "攻撃1"},
	 {"attack2", "攻撃2"},
	 {"slash1", "斬る1"},
	 {"slash2", "斬る2"},
	 {"slash3", "斬る3"},
	 {"slash4", "斬る4"},
	 {"slash5", "斬る5"},
	 {"slash6", "斬る6"},
	 {"slash7", "斬る7"},
	 {"slash8", "斬る8"},
	 {"slash9", "斬る9"},
	 {"slash10", "斬る10"},
	 {"slash11", "斬る11"},
	 {"clock", "時計"},
	 {"blind", "暗闇"},
	 {"darkness1", "暗黒1"},
	 {"darkness2", "暗黒2"},
	 {"darkness3", "暗黒3"},
	 {"darkness4", "暗黒4"},
	 {"darkness5", "暗黒5"},
	 {"darkness6", "暗黒6"},
	 {"song", "歌"},
	 {"poison", "毒"},
	 {"water1", "水1"},
	 {"water2", "水2"},
	 {"water3", "水3"},
	 {"water4", "水4"},
	 {"water5", "水5"},
	 {"water6", "水6"},
	 {"decision1", "決定1"},
	 {"decision2", "決定2"},
	 {"silence", "沈黙"},
	 {"sea1", "海1"},
	 {"sea2", "海2"},
	 {"collapse1", "消滅1"},
	 {"collapse2", "消滅2"},
	 {"confusion", "混乱"},
	 {"fire1", "炎1"},
	 {"fire2", "炎2"},
	 {"fire3", "炎3"},
	 {"fire4", "炎4"},
	 {"fire5", "炎5"},
	 {"fire6", "炎6"},
	 {"fire7", "炎7"},
	 {"fire8", "炎8"},
	 {"explosion1", "爆発1"},
	 {"explosion2", "爆発2"},
	 {"explosion3", "爆発3"},
	 {"explosion4", "爆発4"},
	 {"explosion5", "爆発5"},
	 {"explosion6", "爆発6"},
	 {"explosion7", "爆発7"},
	 {"sleep", "睡眠"},
	 {"sandstorm", "砂けむり"},
	 {"holy1", "神聖1"},
	 {"holy2", "神聖2"},
	 {"holy3", "神聖3"},
	 {"holy4", "神聖4"},
	 {"holy5", "神聖5"},
	 {"holy6", "神聖6"},
	 {"holy7", "神聖7"},
	 {"holy8", "神聖8"},
	 {"holy9", "神聖9"},
	 {"move", "移動"},
	 {"pollen", "花粉"},
	 {"fall1", "落ちる1"},
	 {"fall2", "落ちる2"},
	 {"raise1", "蘇生1"},
	 {"raise2", "蘇生2"},
	 {"raise3", "蘇生3"},
	 {"escape", "逃走"},
	 {"key", "鍵"},
	 {"bell", "鐘"},
	 {"close1", "閉める1"},
	 {"close2", "閉める2"},
	 {"open1", "開ける1"},
	 {"open2", "開ける2"},
	 {"rain1", "雨1"},
	 {"rain2", "雨2"},
	 {"thunder1", "雷1"},
	 {"thunder2", "雷2"},
	 {"thunder3", "雷3"},
	 {"thunder4", "雷4"},
	 {"thunder5", "雷5"},
	 {"thunder6", "雷6"},
	 {"thunder7", "雷7"},
	 {"thunder8", "雷8"},
	 {"thunder9", "雷9"},
	 {"thunder10", "雷10"},
	 {"fog1", "霧1"},
	 {"fog2", "霧2"},
	 {"wave1", "音波1"},
	 {"wave2", "音波2"},
	 {"wind1", "風1"},
	 {"wind2", "風2"},
	 {"wind3", "風3"},
	 {"wind4", "風4"},
	 {"wind5", "風5"},
	 {"wind6", "風6"},
	 {"wind7", "風7"},
	 {"wind8", "風8"},
	 {"wind9", "風9"},
	 {"wind10", "風10"},
	 {"wind11", "風11"},
	 {"magic1", "魔法1"},
	 {"magic2", "魔法2"},

	 // Don Miguel's English translation names
	 {"success1", "あたり1"},
	 {"success2", "あたり2"},
	 {"up", "アップ"},
	 {"glass", "ガシャン"},
	 {"cansel1", "キャンセル1"},
	 {"cansel2", "キャンセル2"},
	 {"numbness1", "しびれ1"},
	 {"numbness2", "しびれ2"},
	 {"numbness3", "しびれ3"},
	 {"down", "ダウン"},
	 {"power", "にらみ"},
	 {"failure1", "はずれ1"},
	 {"failure2", "はずれ2"},
	 {"buzzer1", "ブザー1"},
	 {"buzzer2", "ブザー2"},
	 {"breast", "ブレス"},
	 {"cold1", "冷気1"},
	 {"cold2", "冷気2"},
	 {"cold3", "冷気3"},
	 {"cold4", "冷気4"},
	 {"cold5", "冷気5"},
	 {"cold6", "冷気6"},
	 {"cold7", "冷気7"},
	 {"cold8", "冷気8"},
	 {"cold9", "冷気9"},
	 {"cold10", "冷気10"},
	 {"cold11", "冷気11"},
	 {"absorption1", "吸収1"},
	 {"absorption2", "吸収2"},
	 {"evasion1", "回避1"},
	 {"evasion2", "回避2"},
	 {"knock", "壁1"}, // does not contain barrier1
	 {"knock", "壁2"}, // does not contain barrier2
	 {"refer book", "巻き付き"},
	 {"fight1", "戦闘1"},
	 {"fight2", "戦闘2"},
	 {"kill1", "斬る1"},
	 {"kill2", "斬る2"},
	 {"kill3", "斬る3"},
	 {"kill4", "斬る4"},
	 {"kill5", "斬る5"},
	 {"kill9", "斬る6"}, // does not contain slash6
	 {"kill7", "斬る7"},
	 {"kill8", "斬る8"},
	 {"kill9", "斬る9"},
	 {"kill10", "斬る10"},
	 {"kill11", "斬る11"},
	 {"darkness", "暗闇"},
	 {"dark1", "暗黒1"},
	 {"dark2", "暗黒2"},
	 {"dark3", "暗黒3"},
	 {"dark4", "暗黒4"},
	 {"dark5", "暗黒5"},
	 {"kill6", "暗黒6"},
	 {"annihilation1", "消滅1"},
	 {"annihilation2", "消滅2"},
	 {"chaos", "混乱"},
	 {"flame1", "炎1"},
	 {"flame2", "炎2"},
	 {"flame3", "炎3"},
	 {"flame4", "炎4"},
	 {"flame5", "炎5"},
	 {"flame6", "炎6"},
	 {"flame7", "炎7"},
	 {"flame8", "炎8"},
	 {"sand storm", "砂けむり"},
	 {"movement", "移動"},
	 {"rebirth1", "蘇生1"},
	 {"rebirth2", "蘇生2"},
	 {"rebirth3", "蘇生3"},
	 {"sonic1", "音波1"},
	 {"sonic2", "音波2"},
	 {"wall1", "魔法1"},
	 {"wall2", "魔法2"}
	};

	RTP_TABLE_2000["system"] = {
	 // Official English translation names
	 {"system", "システム"},

	 // Orphaned Don Miguel's 2000 RTP extras pointing to nearest match
	 {"royal", "システム"}
	};

	RTP_TABLE_2000["title"] = {
	 // Official English translation names
	 {"title1", "タイトル1"},
	 {"title2", "タイトル2"},
	 {"title3", "タイトル3"},
	 {"title4", "タイトル4"}
	};
}
